Summary: The Linux kernel (the core of the Linux operating system)

# What parts do we want to build?  We must build at least one kernel.
# These are the kernels that are built IF the architecture allows and
# no contrary --with/--without arguments are given on the command line.

%define buildup 1
%define buildsmp 1
%define buildBOOT 0
%define buildbigmem 0
%define builddebug 0
%define buildjensen 0
%define buildtape 0
%define buildBOOTtape 0
%define buildUML 0

# disable some dependencies to speed up build
%define makedependall 0
# include provides for the kernel version without the release
# these are is the normal redhat provides tags
%define provideversiononly 1
# include provides for kernel versioning
# needed so that alsa under apt can depend on proper kernel
%define providekernelversion 1
# use the redhat patch set
%define redhatpatches 0
# define the redhat release we are compiling on
%define redhatrelease  %(awk '/Fedora/{print $4};/Red Hat/{print $5}' 2>/dev/null </etc/redhat-release)

# Versions of various parts

#
# Polite request for people who spin their own kernel rpms:
# please modify the "release" field in a way that identifies
# that the kernel isn't the stock RHL kernel, for example by
# adding some text to the end of the version number.
#
%define release 1.ll
%define sublevel 23
%define kversion 2.4.%{sublevel}
# /usr/src/%{kslnk} -> /usr/src/linux-%{KVERREL}
%define kslnk linux-2.4

# groups of related archs
%define all_mips mips mipsel
%define all_arm arm armv4l
%define all_ppc ppc ppciseries ppcpseries ppc64
%define all_x86 i386 i686 i586 athlon x86_64
#define all_x86 i686 i386 i586 athlon

%if "%{redhatrelease}" == "9" || "%{redhatrelease}" == "1"
%define nptlarchs %{all_x86}
#define nptlarchs noarch
%else
#%define nptlarchs %{all_x86}
%define nptlarchs noarch
%endif

%if "%{redhatrelease}" == "1"
%define gccversion CC=gcc32 
%else
%define gccversion %{nil}
%endif

# features
# note: do not enable both debugging and ikd, as ikd includes debugging already
%define debugging 0
%define ikd 0
%define ibcs 0

%ifarch %{all_x86}
%define aio 1
%else
%define aio 0
%endif

# disk space requirements to test before build, in megabytes
# ~30M per kernel + ~100M for source plus fudge factor
%define RPM_BUILD_ROOT_space 300
# ~200M for build kernel source tree plus fudge factor
%define RPM_BUILD_DIR_space 200

# disable build root strip policy
%define __spec_install_post /usr/lib/rpm/brp-compress || :

# RPM foo magic
%define _missing_doc_files_terminate_build    0
%define _unpackaged_files_terminate_build 0
%define debug_package %{nil}

# now we need a %{_mystrip} macro to allow cross-compiling
%{expand: %%define go_for_%{_target_cpu}_%{_arch} yadda}
%{expand: %%define _mystrip %{?go_for_ia64_i386:ia64-linux-strip}%{!?go_for_ia64_i386:strip}}

# Enable this to build a board-specific kernel configuration 
# some architectures have LOTS of different setups and this 
# is a way to deal with that cleanly.
#
#define targetboard assabet
%define dashtargetboard %{?targetboard:-%{targetboard}}
%define withtargetboard 0
%{?targetboard: %{expand: %%define withtargetboard 1}}
	
# Override generic defaults with per-arch defaults (which can
# themselves be overridden with --with/--without).  These must
# ONLY be "0", never "1"

# First, architecture-specific kernels off on all other archs (ifnarch)
%ifnarch i686
%define buildbigmem 0
%define builddebug 0
%define buildUML 0
%endif
%ifnarch s390 s390x
%define buildBOOTtape 0
%define buildtape 0
%endif
%ifnarch alpha
# jensen kernel, only for alpha.  Old, broken broken alpha.
%define buildjensen 0
%endif
%ifnarch i386 s390 s390x alpha ppcpseries
%define buildBOOT 0
%endif
# For board-specific kernels, build only the normal kernel (which may actually be smp, not up).
%if %{withtargetboard}
%define buildsmp 0
%define buildBOOT 0
%define buildbigmem 0
%define builddebug 0
%define buildjensen 0
%define buildtape 0
%define buildBOOTtape 0
%define buildUML 0
%endif

# Second, per-architecture exclusions (ifarch)
%ifarch %{all_arm} sh %{all_mips}
%define buildsmp 0
%endif
%ifarch i386
%define buildsmp 0
%endif
%ifarch s390 s390x
%define buildsmp 0
%endif
%ifarch ia64
%define buildBOOT 0
%endif
%ifarch ppc
%define buildBOOT 0
%define buildsmp 0
%endif


# allow --with[out] <feature|kernel> at rpm command line build
# e.g. --with smp --without smp --without BOOT --without bigmem --with ibcs
# --with overrides --without
%{?_without_up: %{expand: %%define buildup 0}}
%{?_without_smp: %{expand: %%define buildsmp 0}}
%{?_without_BOOT: %{expand: %%define buildBOOT 0}}
%{?_without_bigmem: %{expand: %%define buildbigmem 0}}
%{?_without_debug: %{expand: %%define builddebug 0}}
%{?_without_jensen: %{expand: %%define buildjensen 0}}
%{?_without_tape: %{expand: %%define buildtape 0}}
%{?_without_BOOTtape: %{expand: %%define buildBOOTtape 0}}
%{?_without_tux: %{expand: %%define tux 0}}
%{?_without_debugging: %{expand: %%define debugging 0}}
%{?_without_ikd: %{expand: %%define ikd 0}}
%{?_without_ibcs: %{expand: %%define ibcs 0}}
%{?_with_up: %{expand: %%define buildup 1}}
%{?_with_smp: %{expand: %%define buildsmp 1}}
%{?_with_BOOT: %{expand: %%define buildBOOT 1}}
%{?_with_bigmem: %{expand: %%define buildbigmem 1}}
%{?_with_debug: %{expand: %%define builddebug 1}}
%{?_with_jensen: %{expand: %%define buildjensen 1}}
%{?_with_tape: %{expand: %%define buildtape 1}}
%{?_with_BOOTtape: %{expand: %%define buildBOOTtape 1}}
%{?_with_tux: %{expand: %%define tux 1}}
%{?_with_debugging: %{expand: %%define debugging 1}}
%{?_with_ikd: %{expand: %%define ikd 1}}
%{?_with_ibcs: %{expand: %%define ibcs 1}}

# we can't test values inline, only whether a macro exists
%{expand: %%define buildup_%{buildup} yadda}
%{expand: %%define buildsmp_%{buildsmp} yadda}
%{expand: %%define buildBOOT_%{buildBOOT} yadda}
%{expand: %%define buildbigmem_%{buildbigmem} yadda}
%{expand: %%define builddebug_%{builddebug} yadda}
%{expand: %%define buildjensen_%{buildjensen} yadda}
%{expand: %%define buildtape_%{buildtape} yadda}
%{expand: %%define buildBOOTtape_%{buildBOOTtape} yadda}
%{expand: %%define ikd_%{ikd} yadda}
%{expand: %%define ibcs_%{ibcs} yadda}
%{expand: %%define debuglevel_%{debugging} yadda}

%{expand: %%define kernel_conflicts  ppp <= 2.3.15, pcmcia-cs <= 3.1.20, isdn4k-utils <= 3.0, mount < 2.10r-5, nfs-utils < 0.3.1, cipe < 1.4.5, tux < 2.1.0, kudzu <= 0.92, e2fsprogs < 1.22, initscripts < 6.41, dev < 3.2-7, iptables < 1.2.5-3}

%define BOOT_kernel_prereq fileutils, modutils >= 2.4.18
%define kernel_prereq %{BOOT_kernel_prereq}, initscripts >= 5.83, mkinitrd >= 3.2.6
%ifarch ia64
%define initrd_dir /boot/efi/redhat
%else
%define initrd_dir /boot
%endif

%ifarch %{all_x86}
%define kernel_glob vmlinu?-%{KVERREL}
%define debug_kernel_glob vmlinu?-%{KVERREL}
%endif
%ifarch %{all_ppc}
%define kernel_glob vmlinu?-%{KVERREL}
%define debug_kernel_glob vmlinu?-%{KVERREL}
%endif
%ifarch ia64
# <sigh>, no GLOB_BRACE for filelists, efi needs to be done separately
%define kernel_glob vmlinuz-%{KVERREL}
%define debug_kernel_glob vmlinu?-%{KVERREL}
%endif
%ifarch alpha
%define kernel_glob vmlinu?-%{KVERREL}
%define debug_kernel_glob vmlinu?-%{KVERREL}
%endif
%ifarch s390 s390x
%define kernel_glob vmlinu?-%{KVERREL}
%define debug_kernel_glob vmlinu?-%{KVERREL}
%endif
%ifarch %{all_arm} sh %{all_mips}
%define kernel_glob vmlinu?-%{KVERREL}
%define debug_kernel_glob vmlinu?-%{KVERREL}
%endif

Name: kernel
Version: %{kversion}
Release: %{?release_prefix:%{release_prefix}.}%{release}%{?release_suffix:.%{release_suffix}}%{?targetboard:%{targetboard}}%{?debuglevel_1:.dbg}
%define KVERREL %{PACKAGE_VERSION}-%{PACKAGE_RELEASE}
License: GPL
Group: System Environment/Kernel
ExclusiveArch: %{all_x86} s390 s390x %{all_ppc} %{all_arm} sh %{all_mips}
ExclusiveOS: Linux
Obsoletes: kernel-modules, kernel-sparc
%if "%{provideversiononly}" == "1"
Provides: kernel = %{version}
%endif
%if "%{providekernelversion}" == "1"
Provides: kernel-version-%{_target_cpu} = %{version}-%{release}
%endif
Provides: module-info
%ifarch %{all_x86} ia64
Provides: kernel-drm = 4.1.0, kernel-drm = 4.2.0, kernel-drm = 4.3.0, kernel-drm = 4.2.99.3
%endif
Autoreqprov: no
Prereq: %{kernel_prereq}
Conflicts: %{kernel_conflicts}

BuildPreReq: modutils >= 2.4.13, patch >= 2.5.4, bash >= 2.03, sh-utils, gnupg, tar
BuildPreReq: bzip2, findutils, dev, gzip, m4
%ifarch s390 s390x
BuildRequires: gcc >= 2.95.3
%else
%ifarch %{all_ppc}
BuildRequires: gcc >= 2.96-75
%else
BuildRequires: gcc >= 2.96-98
%if "%{redhatrelease}" == "1"
BuildRequires: gcc32
%endif
%endif
%endif

Source0: ftp://ftp.kernel.org/pub/linux/kernel/v2.4/linux-%{kversion}.tar.bz2
Source4: README.kernel-sources

# helper script for upgrading configurations
Source5: kernel-update-configs

Source10: COPYING.modules
Source11: module-info
Source14: kernel-2.4-BuildASM.sh
Source15: linux-rhconfig.h
Source16: linux-merge-config.awk
Source17: linux-merge-modules.awk
Source18: genkey

Source20: kernel-%{kversion}-i386.config
Source21: kernel-%{kversion}-i386-smp.config
Source22: kernel-%{kversion}-i386-BOOT.config
Source23: kernel-%{kversion}-alpha.config
Source24: kernel-%{kversion}-alpha-smp.config
Source25: kernel-%{kversion}-sparc.config
Source26: kernel-%{kversion}-sparc-smp.config
Source27: kernel-%{kversion}-sparc64.config
Source28: kernel-%{kversion}-sparc64-smp.config
Source29: kernel-%{kversion}-i686.config
Source30: kernel-%{kversion}-i686-smp.config
Source31: kernel-%{kversion}-alpha-BOOT.config
Source32: kernel-%{kversion}-sparc-BOOT.config
Source33: kernel-%{kversion}-sparc64-BOOT.config
Source34: kernel-%{kversion}-i586.config
Source35: kernel-%{kversion}-i586-smp.config
# since there are no space issues, a -BOOT is rather pointless
Source36: kernel-%{kversion}-ia64.config
Source37: kernel-%{kversion}-ia64-smp.config
Source38: kernel-%{kversion}-i686-bigmem.config
Source39: kernel-%{kversion}-i686-debug.config
Source40: kernel-%{kversion}-athlon.config
Source41: kernel-%{kversion}-athlon-smp.config
Source42: kernel-%{kversion}-alpha-jensen.config
Source43: kernel-%{kversion}-s390-BOOTtape.config
Source44: kernel-%{kversion}-s390-BOOT.config
Source45: kernel-%{kversion}-s390-tape.config
Source46: kernel-%{kversion}-s390.config
Source47: kernel-%{kversion}-ia64-BOOT.config
Source48: kernel-%{kversion}-x86_64.config
Source49: kernel-%{kversion}-x86_64-smp.config
Source50: installkernel.iSeries
Source51: installcmdline.iSeries
Source52: kernel-%{kversion}-ppc.config
Source53: kernel-%{kversion}-ppcpseries.config
Source54: kernel-%{kversion}-ppcpseries-smp.config
Source55: kernel-%{kversion}-ppcpseries-BOOT.config
Source56: kernel-%{kversion}-s390x-BOOTtape.config
Source57: kernel-%{kversion}-s390x-BOOT.config
Source58: kernel-%{kversion}-s390x-tape.config
Source59: kernel-%{kversion}-s390x.config
Source60: kernel-%{kversion}-ppc64.config
Source61: kernel-%{kversion}-ppc64-BOOT.config
Source62: kernel-%{kversion}-i686-uml.config
Source63: kernel-%{kversion}-sh.config
Source64: kernel-%{kversion}-mips.config

# the following is for embedded systems where the %{targetboard} variable
# is set
%if %{withtargetboard}
Source70: kernel-%{kversion}-%{_target_cpu}-%{targetboard}.config
%endif

####Source80: linux-2.4.7-ikd.patch

Source100: linux_logo.h

#
# Patches 0 through 100 are meant for core subsystem upgrades
#

Patch1: patch-2.4.19-pre7-noieee1934.bz2
Patch2: patch-2.4.19-pre7-ac2.bz2
Patch9: patch-2.4.19-pre7.bz2

Patch3: linux-2.4.17-selected-ac-bits.patch
Patch4: linux-2.4.18-mmap_fix.patch

# Compile with kgcc ifpresent
Patch8: linux-2.4.0-kgcc.chmou.patch


# 
# Patches 100 through 400 are architecture specific patches
# Each architecture has 20 slots reserved.
#

# IA64
Patch100: linux-2.4.17-ia64-core.patch
Patch101: linux-2.4.9-ia64-junk.patch
Patch102: linux-2.4.9-ia64-cs4281.patch
Patch103: linux-2.4.9-ia64-compile.patch
Patch104: linux-2.4.1-ia64-swiotlb.patch
Patch105: linux-2.4.5-ia64-unaligned.patch
Patch106: linux-2.4.9-ia64-unwind.patch
Patch107: linux-2.4.9-ia64-trapinfo.patch
Patch108: linux-2.4.3-ia64-ppp.patch
Patch109: linux-2.4.17-ia64-latebits.patch
Patch110: linux-2.4.9-ia64-updates.patch
Patch111: linux-2.4.17-ia64-scheduler.patch


# Alpha
Patch120: linux-2.3.99-alpha.patch
Patch121: linux-2.4.1-alphaksyms.patch
Patch124: linux-2.4.3-nautilus.patch
Patch125: linux-2.4.5-alphaexports.patch


# Sparc / Sparc64
Patch140: linux-2.3.99p3p6-sparc.patch

# x86
Patch160: linux-2.4.1-brokenmptable.patch

# ppc
Patch184: linux-2.4.13-ppc-ac.patch

# s390 / s390x
Patch200: linux-2.4.9-s390-ac14.patch
Patch205: linux-2.4.9-s390-rh.patch
Patch206: linux-2.4.9-s390-dasd.patch
Patch207: linux-2.4.9-s390-54390.patch
Patch208: linux-2.4.17-scheduler-s390.patch
Patch209: linux-2.4.18-s390-entryoff.patch
Patch210: linux-2.4.18-s390-backport.patch

# X86-64 is 220 - 239

# arm
# Cleanup for applying a slightly older RMK patch
#Patch240: linux-2.4.18-rc1-revert-for-17rmk.patch
#Patch241: ftp://ftp.arm.linux.org.uk/pub/linux/arm/source/kernel-patches/v2.4/patch-2.4.17-rmk5.gz
#Patch242: linux-2.4.17-rmk4-to-18-rc1.patch
Patch241: linux-2.4.17-rmk5-hackedfor18rc1-v2.patch
# Back out (temporarily) the change to drivers/Makefile to prevent conflicts
#Patch243: linux-2.4.12-remove-drivers-serial.patch
# ... and put it back again at the end
Patch244: linux-2.4.12-add-drivers-serial.patch
Patch245: linux-2.4.17-arm-rmap.patch
Patch246: linux-2.4.17-arm-rmap-discontig.patch

# sh
Patch260: linux-2.4.16-sh-20011213.patch
# Back out (temporarily) the change to drivers/Makefile to prevent conflicts
Patch261: linux-2.4.16-sh-remove-maple.patch
# ... and put it back again at the end
Patch262: linux-2.4.16-sh-add-maple.patch

# mips
Patch280: linux-2.4.16-mips-20011220.patch
Patch281: linux-2.4.13-mips-load-mips2.patch
Patch282: linux-2.4.16-show_stack_proto.patch
Patch283: linux-2.4.16-diskonchip.patch
#
# Patches 400 through 599 are the TUX patches
#

Patch400: linux-2.4.15-tux2.patch


#
# Patches 600 through 1000 are reserved for bugfixes to the core system
# and patches related to how RPMs are build
#

Patch600: linux-2.4.0-nonintconfig.patch
Patch601: linux-2.4.22-forcegcc32.patch
Patch620: linux-2.4.1-quiet.patch
Patch630: linux-2.4.7-quotareturn.patch
Patch640: linux-2.2.16-rhconfig.patch
Patch650: linux-2.4.2-changeloop.patch
Patch660: linux-2.4.5-config-small.patch
Patch661: linux-2.4.20-edd.patch
Patch662: linux-2.4.20-edd-allocate.patch
Patch680: linux-2.4.1-scsi-reset.patch
Patch690: linux-2.4.2-pge.patch
Patch700: linux-2.4.2-scsi_scan.patch
Patch710: linux-2.4.6-oomavoidance.patch
Patch720: linux-2.4.9-kksymoops.patch
Patch721: linux-2.4.9-kallsyms.patch
Patch730: linux-2.4.7-highmemspeed.patch
Patch740: linux-2.4.17-lowlatency.patch
Patch760: linux-2.4.17-gccchoice.patch
Patch771: linux-2.4.17-scheduler-ppc.patch
Patch772: linux-2.4.17-noscheduler.patch
Patch780: linux-2.4.17-blockhighmem.patch
Patch790: linux-2.4.17-logo.patch
Patch810: linux-2.4.17-iorl.patch
Patch820: linux-2.4.17-aic7xxx.patch
Patch830: linux-2.4.18-vfscleanups.patch
Patch850: linux-2.4.18-dmi-hall-of-shame.patch
Patch860: linux-2.4.18-blockdev-updates.patch

#
# Patches 1000 to 5000 are reserved for bugfixes to drivers and filesystems
#

Patch1030: linux-2.4.0-test11-vidfail.patch
Patch1040: linux-2.4.0-e820.patch
Patch1050: linux-2.4.0-raid5xor.patch
Patch1060: linux-2.4.2-mem-setup-fix.patch
Patch1070: linux-2.4.2-page_bitmap.patch
Patch1080: linux-2.4.0-apic-quiet.patch
Patch1090: linux-2.4.3-rawio.patch
Patch1100: linux-2.4.3-pcipenalty.patch
Patch1110: linux-2.4.7-usb-bug50218.patch
Patch1120: linux-2.4.2-keyboardsilence.patch
Patch1130: linux-2.4.3-upapic.patch
Patch1150: linux-2.4.18-pcnet32.patch
Patch1160: linux-2.4.5-xircom-cb.patch
Patch1170: linux-2.4.7-scsitimeout.patch
Patch1180: linux-2.4.9-freevxfs.patch
Patch1190: linux-2.4.7-ewrk3.patch
Patch1200: linux-2.4.9-nmiprofiling.patch
Patch1210: linux-2.4.18-moreunnamed.patch
Patch1240: linux-2.4.17-usb-55878.patch
Patch1250: linux-2.4.17-lvm-1.0.3.update.diff
Patch1251: linux-2.4.17-lvm-bulkcopy.patch
Patch1252: linux-2.4.17-lvm-pvmove.patch
Patch1253: linux-2.4.17-mempool.patch
Patch1254: linux-2.4.17-lvm-fixes.patch
Patch1255: linux-2.4.18-lvm-VFSlock.patch
Patch1261: linux-2.4.18-input-35215.patch
Patch1270: linux-2.4.9-pcmcia-ethtool.patch
Patch1280: linux-2.4.18-tg3.patch
Patch1290: linux-2.4.18-compaqupdate.patch
Patch1300: linux-2.4.18-nicdrivers.patch
Patch1310: linux-2.4.18-megaraid.patch
Patch1320: linux-2.4.18-ide-update.patch
Patch1330: linux-2.4.18-scsi-whitelist.patch
Patch1340: linux-2.4.9-scsilun0.patch
Patch1350: linux-2.4.18-ips.patch
Patch1360: linux-2.4.18-usb-61820.patch
Patch1370: linux-2.4.18-acct-32bit-uid-gid.patch
Patch1380: linux-2.4.9-fstat.patch
Patch1390: linux-2.4.18-irixnfs.patch
Patch1400: linux-2.4.18-ext3-updates.patch
Patch1410: linux-2.4.18-wacom-usb.patch
Patch1420: linux-2.4.7-suspend.patch
Patch1430: linux-2.4.18-aacraid.patch
Patch1440: linux-2.4.18-loopfixes.patch
Patch1450: linux-2.4.18-orinoco.patch
Patch2140: linux-2.4.9-ide-tape.patch
Patch2380: linux-2.4.17-watchdog-nowayout.patch
Patch2400: linux-2.4.18-feral-qlogic-isp.patch
Patch2401: linux-2.4.22-feral-qlogic-isp.patch
Patch2410: linux-2.4.9-feral-qlogic-isp-config.patch
Patch2420: linux-2.4.22-gericom.patch

#
# Patches 5000 to 5800 are reserved for new drivers
#
Patch5000: linux-2.4.9-addon.patch
Patch5001: linux-2.4.22-addon.patch
Patch5010: linux-2.4.18-megarac.patch
Patch5020: linux-2.4.9-bcm5700.patch  
Patch5021: linux-2.4.8-bcm5700-224.patch
Patch5030: linux-2.4.0-wvlan-cs.patch
Patch5031: linux-2.4.7-wvlan_cs.patch
Patch5040: linux-2.4.1-netfilter-addons.patch
Patch5050: linux-2.4.18-ecc.patch
Patch5070: linux-2.4.2-alternateairo.patch
Patch5080: linux-2.4.5-mxt.patch	
Patch5081: linux-2.4.6-mxtfix.patch
Patch5082: linux-2.4.6-mxtbios.patch
Patch5090: linux-2.4.6-bcm5820.patch
Patch5091: linux-2.4.6-bcm5820-2.patch
Patch5092: linux-2.4.7-bcm5820-16.patch
Patch5093: linux-2.4.7-bcm5820-17.patch
Patch5094: linux-2.4.18-bcm5820-update.patch
Patch5120: linux-2.4.18-iscsi.patch
Patch5130: linux-2.4.18-e1000.patch
Patch5140: linux-2.4.18-e100.patch
Patch5170: linux-2.4.7-avm_cs.patch
Patch5180: linux-2.4.7-tulip.patch
Patch5190: linux-2.4.0-cipe-1.4.5.patch
Patch5191: linux-2.4.2-cipe.patch
Patch5192: linux-2.4.9-cipenat.patch
Patch5200: linux-2.4.9-lm_sensors.patch
Patch5210: linux-2.4.9-qla2200.patch
Patch5220: linux-2.4.9-aep.patch
Patch5230: linux-2.4.16-bridgefilter.patch
Patch5240: linux-2.4.18-aic79xx.patch
Patch5250: linux-2.4.18-afs.patch


#
# Patches 5800 to 6000 are the HA/IPVS patches
#
#Patch5800: linux-2.4.2-ipvs.patch
#Patch5810: linux-2.4.5-ipvsfix.patch
#Patch5820: linux-2.4.5-ipvs-0.8.1.patch
Patch5830: linux-2.4.15-ipvs-0.9.7.patch

#
# Patches 6000 and later are reserved for %if {something} patches
#
Patch6000: linux-2.4.17-linux-abi.patch


# debugging
#Patch7000: linux-2.4.2-aviro-buffer.c.patch
#Patch7030: linux-2.4.2-vmpoison.patch
#Patch7040: linux-2.4.1-debugging.patch
#Patch7050: linux-2.4.2-smbdebug.patch


#
# 10000 to 20000 is for stuff that has to come last due to the
# amount of drivers they touch
#
# Patch10000: linux-2.4.0-sard.patch
# fix a lot of warnings in the plain kernel and previous patches
Patch10010: linux-2.4.1-compilefailure.patch

# several small tweaks not worth their own patch
Patch10020: linux-2.4.18-smallpatches.patch

# aio.
Patch10100: linux-2.4.18-rh-aio-20020326.patch


###############################
# 20000 upwards, NandoPatchLand
###############################

# 2.4.23-rc3
Patch20010: patch-2.4.23-rc3.bz2

# Alan Cox series
# Patch20101: patch-2.4.21-pre4-ac1.bz2

# enable CAP_SETPCAP capability on init
# ftp://ftp.kernel.org/pub/linux/libs/security/linux-privs/kernel-2.2/capfaq-0.2.txt
Patch20000: linux-cap_setpcap.patch

# low latency patch
Patch20001: 2.4.23-test5-low-latency.patch.gz

# drm low latency patch
Patch20002: linux-drm-lowlat.patch

# preemptible kernel patch
Patch20004: preempt-kernel-rml-2.4.22.patch

# acpi patch (has been merge into 2.4.22 final)
Patch20007: acpi-20030813-2.4.22-rc2.diff.gz

# Read Latency2 (adapted for 2.4.22-rc2):
# from Con Koliva's patches
Patch20045: patch-readlatency2-2.4.22-rc2.patch.bz2

# Desktop Tuning 1 (adapted for 2.4.22-rc2, from Con Koliva's page):
Patch20046: patch-desktoptuning1-2.4.22-rc2.patch.bz2

# Variable HZ setting (from Con Koliva's page)
Patch20047: patch-1030_VH_0306200116_2.4.21-ck2.bz2

# Desktop Tuning 2 (from Con Koliva's page)
Patch20048: patch-1031_DT2_0306200119_2.4.21-ck2.bz2

# alsa rtc patch
Patch20072: rtc-2.4.23-test5.patch

# drm updates from the latest redhat kernel
Patch20073: linux-2.4.20-drm43.patch

# speedup for cdrom audio extraction, requested by digitalsin at earthlink
Patch20074: ide-akpm.patch.txt

# i2c 2.8.1 kernel modules
Patch20075: i2c-2.8.1-2.4.22-rc1.patch.gz
# lm_sensors 2.8.1 kernel modules
Patch20076: lm_sensors-2.8.1-2.4.22-rc1.patch.gz

# extra i2c patches
Patch20077: linux-2.4.22-i2c-2.8.1-drivers-acorn-char.diff
Patch20078: linux-2.4.22-i2c-2.8.1-drivers-i2c-Config.in.diff
Patch20079: linux-2.4.22-i2c-2.8.1-drivers-i2c-i2c-adap-ite.c.diff
Patch20080: linux-2.4.22-i2c-2.8.1-drivers-i2c-i2c-algo-ite.c.diff
Patch20081: linux-2.4.22-i2c-2.8.1-drivers-i2c-i2c-algo-sibyte.c.diff
Patch20082: linux-2.4.22-i2c-2.8.1-drivers-i2c-i2c-max1617.c.diff
Patch20083: linux-2.4.22-i2c-2.8.1-drivers-i2c-i2c-sibyte.c.diff
Patch20084: linux-2.4.22-i2c-2.8.1-drivers-i2c-Makefile.diff
Patch20085: linux-2.4.22-i2c-2.8.1-drivers-i2c-scx200_acb.c.diff
Patch20086: linux-2.4.22-i2c-2.8.1-drivers-i2c-scx200_i2c.c.diff
Patch20087: linux-2.4.22-i2c-2.8.1-drivers-ieee1394.diff

Patch20088: linux-2.4.22-i2c-2.8.1-drivers-media-video.diff

Patch20089: linux-2.4.22-i2c-2.8.1-drivers-pcmcia.diff
Patch20090: linux-2.4.22-i2c-2.8.1-drivers-sound-dmasound.diff
Patch20091: linux-2.4.22-i2c-2.8.1-drivers-video-matrox.diff

# nfs patches for 2.4.22
# http://www.fys.uio.no/~trondmy/src/Linux-2.4.x/2.4.23-pre9/
Patch20100: linux-2.4.23-01-fix_osx.dif
Patch20101: linux-2.4.23-02-fix_lockd3.dif
Patch20102: linux-2.4.23-03-soft2.dif
Patch20103: linux-2.4.23-04-fix_unlink.dif
Patch20104: linux-2.4.23-05-seekdir.dif
Patch20105: linux-2.4.23-06-access.dif
Patch20106: linux-2.4.23-07-pathconf.dif
Patch20107: linux-2.4.23-08-cto2.dif
Patch20108: linux-2.4.23-09-rdplus.dif
Patch20109: linux-2.4.23-10-sock_disconnect.dif

# fix compilation of sk98lin driver
Patch20150: linux-2.4.23-test5-sk98lin.patch

# fixes for unicorn usb drivers
# from: http://www.bewan.com/bewan/drivers/bapst-0.6.1.tar.gz
Patch20160: linux-2.4.21-usb-uhci.patch
Patch20161: linux-2.4.21-usb-ohci.patch

# fix for airo.c (to compile with kernel named 2.4.22)
Patch20170: linux-2.4.22-airo.patch

# fix for redefinition of symbol due to kernel version
Patch20180: kernel-2.4.22-23rc1-nsp32.patch


# END OF PATCH DEFINITIONS

BuildRoot: %{_tmppath}/kernel-%{KVERREL}-root

%package source
Summary: The source code for the Linux kernel.
Group: Development/System
Prereq: fileutils
Requires: gawk
%ifarch s390 s390x
Requires: gcc >= 2.95.3
%else
%ifarch %{all_ppc}
Requires: gcc >= 2.96-75
%else
Requires: gcc >= 2.96-98
%if "%{redhatrelease}" == "1"
Requires: gcc32
%endif
%endif
%endif

%package doc
Summary: Various documentation bits found in the kernel source.
Group: Documentation

%description 
The kernel package contains the Linux kernel (vmlinuz), the core of your
Red Hat Linux operating system.  The kernel handles the basic functions
of the operating system:  memory allocation, process allocation, device
input and output, etc.

%description source
The kernel-source package contains the source code files for the Linux
kernel. These source files are needed to build custom/third party device
drivers. The source files can also be used to build a custom kernel that is
better tuned to your particular hardware, if you are so inclined (and you
know what you're doing).

%description doc
This package contains documentation files form the kernel
source. Various bits of information about the Linux kernel and the
device drivers shipped with it are documented in these files. 

You'll want to install this package if you need a reference to the
options that can be passed to Linux kernel modules at load time.

%package smp
Summary: The Linux kernel compiled for SMP machines.
Group: System Environment/Kernel
%if "%{provideversiononly}" == "1"
Provides: kernel = %{version}
%endif
%if "%{providekernelversion}" == "1"
Provides: kernel-version-smp-%{_target_cpu} = %{version}-%{release}
%endif
Provides: module-info
%ifarch %{all_x86} ia64
Provides: kernel-drm = 4.1.0, kernel-drm = 4.2.0, kernel-drm = 4.3.0, kernel-drm = 4.2.99.3
%endif
Prereq: %{kernel_prereq}
Conflicts: %{kernel_conflicts}

%description smp
This package includes a SMP version of the Linux kernel. It is
required only on machines with two or more CPUs, although it should
work fine on single-CPU boxes.

Install the kernel-smp package if your machine uses two or more CPUs.

%package bigmem
Summary: The Linux Kernel for machines with more than 4 Gigabyte of memory.
Group: System Environment/Kernel
%if "%{provideversiononly}" == "1"
Provides: kernel = %{version}
%endif
%if "%{providekernelversion}" == "1"
Provides: kernel-version-bigmem-%{_target_cpu} = %{version}-%{release}
%endif
Provides: module-info
%ifarch %{all_x86} ia64
Provides: kernel-drm = 4.1.0, kernel-drm = 4.2.0, kernel-drm = 4.3.0, kernel-drm = 4.2.99.3
%endif
Prereq: %{kernel_prereq}
Conflicts: %{kernel_conflicts}
Obsoletes: kernel-enterprise <= 2.4.10


%description bigmem
This package includes a kernel that has appropriate configuration options
enabled for Pentium III machines with 4 Gigabyte of memory or more.

%package uml
Summary: The Linux kernel as normal program
Group: System Environment/Kernel
%if "%{provideversiononly}" == "1"
Provides: kernel-uml = %{version}
%endif
%if "%{providekernelversion}" == "1"
Provides: kernel-version-uml-%{_target_cpu} = %{version}-%{release}
%endif

%description uml
This package includes a linux kernel compiled as normal program.
This provides a sandbox in which experimentation can be done without
harm to the real system, and can also be used for isolation of network
services


%package debug
Summary: The Linux Kernel compiled with options for kernel debugging
Group: System Environment/Kernel
%if "%{provideversiononly}" == "1"
Provides: kernel = %{version}
%endif
%if "%{providekernelversion}" == "1"
Provides: kernel-version-debug-%{_target_cpu} = %{version}-%{release}
%endif
Provides: module-info, kernel-drm = 4.1.0, kernel-drm = 4.2.0, kernel-drm = 4.3.0, kernel-drm = 4.2.99.3
Prereq: %{kernel_prereq}
Conflicts: %{kernel_conflicts}


%description debug 
This package includes a kernel that has several kernel debugging
settings enabled.

%package BOOT
Summary: The version of the Linux kernel used on installation boot disks.
Group: System Environment/Kernel
%if "%{provideversiononly}" == "1"
Provides: kernel = %{version}
%endif
%if "%{providekernelversion}" == "1"
Provides: kernel-version-BOOT-%{_target_cpu} = %{version}-%{release}
%endif
Prereq: %{BOOT_kernel_prereq}
Conflicts: %{kernel_conflicts}

%description BOOT
This package includes a trimmed down version of the Linux kernel.
This kernel is used on the installation boot disks only and should not
be used for an installed system, as many features in this kernel are
turned off because of the size constraints.

%package BOOTsmp
Summary: The Linux kernel used on installation boot disks for SMP machines.
Group: System Environment/Kernel
%if "%{provideversiononly}" == "1"
Provides: kernel = %{version}
%endif
%if "%{providekernelversion}" == "1"
Provides: kernel-version-BOOTsmp-%{_target_cpu} = %{version}-%{release}
%endif
Prereq: %{BOOT_kernel_prereq}
Conflicts: %{kernel_conflicts}

%description BOOTsmp
This package includes a trimmed down version of the Linux kernel. This
kernel is used on the installation boot disks only and should not be used
for an installed system, as many features in this kernel are turned off
because of the size constraints. This kernel is used when booting SMP
machines that have trouble coming up to life with the uniprocessor kernel.

%package jensen
Summary: The Linux Kernel compiled for the Alpha Jensen platform.
Group: System Environment/Kernel
%if "%{provideversiononly}" == "1"
Provides: kernel = %{version}
%endif
%if "%{providekernelversion}" == "1"
Provides: kernel-version-jensen-%{_target_cpu} = %{version}-%{release}
%endif
Prereq: %{kernel_prereq}
Conflicts: %{kernel_conflicts}

%description jensen
This package includes a kernel that has appropriate configuration
options enabled for use on the Alpha Jensen platform.  The Jensen
platform is not supported in the normal generic alpha kernel support.

%package tape
Summary: The Linux Kernel compiled for booting from tape
Group: System Environment/Kernel
%if "%{provideversiononly}" == "1"
Provides: kernel = %{version}
%endif
%if "%{providekernelversion}" == "1"
Provides: kernel-version-tape-%{_target_cpu} = %{version}-%{release}
%endif
Prereq: %{kernel_prereq}
Conflicts: %{kernel_conflicts}

%description tape
This package includes a kernel that has appropriate configuration
options enabled for booting from tape.

%package BOOTtape
Summary: The version of the Linux kernel used on installation boot tapes.
Group: System Environment/Kernel
%if "%{provideversiononly}" == "1"
Provides: kernel = %{version}
%endif
%if "%{providekernelversion}" == "1"
Provides: kernel-version-BOOTtape-%{_target_cpu} = %{version}-%{release}
%endif
Prereq: %{BOOT_kernel_prereq}
Conflicts: %{kernel_conflicts}

%description BOOTtape
This package includes a kernel that has appropriate configuration
options enabled for booting from tape.


%prep

%setup -q -n %{name}-%{version} -c
cd linux-%{version}

#
# Patches 0 through 100 are meant for core subsystem upgrades
# 

%if "%{redhatpatches}" == "0"

# patch with latest pre
# %patch20010 -p1

# patch with latest pre-ac (21-pre4-ac1)
# %patch20101 -p1

# abort on unconfigured options
%patch600 -p1

# force usage of gcc32 to build the kernel.
%if "%{redhatrelease}" == "1"
%patch601 -p1
%endif
%endif


%if "%{redhatpatches}" == "1"

# selected bits from the -ac patch series
%patch3 -p1
# make mmap work for vsyscalls
%patch4 -p1


# 
# Patches 100 through 400 are architecture specific patches
# Each architecture has 20 slots reserved.
#

# IA64
%ifarch ia64
# base ia64 patch from David Mosberger
%patch100 -p1
%patch101 -p1
%patch102 -p1
%patch103 -p1
%patch104 -p1
%patch105 -p1
%patch106 -p1
%patch107 -p1
%patch108 -p1
%patch110 -p1
%endif

# Alpha

# fix some include files
%patch120 -p1
%patch121 -p1
# Alpha Nautilus patch
%patch124 -p1
# exports revisted
#%patch125 -p1


# Sparc / Sparc64

%patch140 -p1

# x86
# work around broken MP tables from bioses
%patch160 -p1

# ppc
# make the ac patch set build
%patch184 -p1

# s390
#  We keep good s390 stuff outside %ifarch as much as practical.
#  It is useful to do "make prep" on i386 and see what failed.
#
# modifications backported from 2.4.9ac14 - incorporated into 2.4.12
#%patch200 -p1
# modifications that are Red Hat Linux specific or from s390-1
%patch205 -p1
# non-working patch
#%patch206 -p1
# dasd supplies garbage in first track (#54390)
#%patch207 -p1
# Ingo's scheduler
%patch208 -p1
# [- Bare offsets obsoleted by the backport]
#%patch209 -p1
# Backport from 2.4.19-pre3 fixes totally hosed 2.4.18.
#%patch210 -p1

#
# X86-64
#

# arm
%ifarch %{all_arm}
#%patch240 -p1
# 2.4.17-rmk5(ish)
%patch241 -p1
#%patch242 -p1
# Back out the addition of the serial and l3 subdirs to drivers/Makefile
#%patch243 -p1
%patch245 -p1
%patch246 -p1
%endif

%ifarch sh
%patch260 -p1
# Back out the addition of the maple subdir to drivers/Makefile
%patch261 -p1
%endif

%ifarch %{all_mips}
%patch280 -p1
%patch281 -p1
%patch282 -p1
%patch283 -p1
%endif

#
# Patches 400 through 500 are the TUX patches
#

%patch400 -p1



#
# Patches 600 through 1000 are reserved for bugfixes to the core system
# and patches related to how RPMs are build
#


# This patch adds a "make oldconfig_nonint" which is non-interactive and
# also gives a list of missing options at the end. Useful for automated
# builds (as used in the Red Hat buildsystem).
%patch600 -p1
# 
# autorun, magicdev and nautilus have the bad habbit of polling the cdrom
# drive every few seconds to see if the user inserted a cdrom.
# This patch makes sure that the printk in the cdrom code is now silent
# otherwise the syslog would fill up fast.
%patch620 -p1
# tty_write_message needs \r\n -- makes quota messages look nicer
%patch630 -p1
#
# Make "make oldconfig" smarter and have it use the config file for the
# currently running kernel as default.
#
%patch640 -p1
# Al Viro's loopback patch 
%patch650 -p1
#
# The installer floppies are extremely tight on diskspace. Introduce
# CONFIG_SMALL that compile-time disables some things not needed in the
# installer kernel to make things fit.
#
%patch660 -p1
#
# PGE is a cpu extension in Intel's Pentium Pro/II/III (also present in
# AMD's cpus). Cyrix and Transmeta cpu's don't have this option. The
# following patch makes PGE a config option we can disable for i686 kernels as
# to allow Cyrix and Transmeta cpus to use this kernel.
#
%patch690 -p1
# fix lun probing on multilun RAID chassis
%patch700 -p1
#
# The following patch is a brute-force hack of making the VM killer 
# less trigger happy in OOM situations.
#
%patch710 -p1
#
# kksymoops - automatically decode oopses/backtraces from within the kernel
%patch720 -p1
%ifarch %{all_x86} s390 s390x %{all_ppc}
%patch721 -p1
%endif
#
# improve IO performance on highmem machines by being smarter
# about bounce buffers. HP measured a 10% performance improvement for
# NFS servers with this.
%patch730 -p1
#
# improve interactive "feel" by reducing latency
# (most but not all of Andrew Morton's low latency patch)
#
%patch740 -p1
#
# prefer gcc 2.96 if present; this allows people to experiment with gcc 3.1
# for userspace while having a "safe" compiler for the kernel
#
%patch760 -p1
#
# Make the arm architecture work with the O(1) scheduler
#
%patch771 -p1
#
# Jens Axboe's blockhighmem patch to eliminate the use of bounce-buffers
# for big machines with 1Gb or more of ram
#
%ifnarch %{all_arm}
%patch780 -p1
%endif
#
# put logo on screen during bootup
%patch790 -p1
#
# scalability patch: split the io_request_lock into per adapter locks
#
%patch810 -p1
# add the iorl related aic7xxx_old changes
%patch820 -p1
#
# backport of VFS cleanups done in 2.5 (and later merged into 2.4.19)
#
%patch830 -p1
#
# update the list of vendors who can't program a bios
#
%patch850 -p1
#
# Bug fixes to core buffer handling for block devices
#
%patch860 -p1


#
# Patches 1000 to 5000 are reserved for bugfixes to drivers and filesystems
#

# add vidfail capability; 
# without this patch specifying a framebuffer on the kernel prompt would
# make the boot stop if there's no supported framebuffer device; this is bad
# for the installer floppy that wants to automatically fall back to textmode
# in that case
%patch1030 -p1
#
# add e820 reporting in /proc; needed for anaconda to find out which
# kernels to install
#
%patch1040 -p1
# raid5 xor fix for PIII/P4, should go away shortly
%patch1050 -p1
#
# mem= command-line adapts itself to existing e820 values.
# without this patch mem=xxxM ignores bios-reserved areas and uses 
# them as RAM. This patch makes the kernel skip these areas.
#
%patch1060 -p1
# conservative zone bitmaps to prevent potential memory corruption
%patch1070 -p1
#
# Silence the APIC errors a bit; they are harmless mostly and can happen
# in normal use.
#
%patch1080 -p1
# fix rawio
%patch1090 -p1
#
# change IRQ penalty for IRQ 12
# This tries to avoid assigning cardbus irq's to irq12 which is "special"
# for certain laptops that emulate PS/2 hardware via SMM mode.
#
%patch1100 -p1
#
# Silence the PS/2 code for USB keyboards
# It's not uncommon to have no PS/2 keyboard these days
#
%patch1120 -p1
#
# work around broken 440GX chipset boards/bioses by adding an "apic" option
# that will use the mptable instead of the $PIRQ table (which the intel bios
# gets horribly wrong and seems very resistant against being fixed). 
#
%patch1130 -p1
#
# update the pcnet32 driver
#
%patch1150 -p1
#
# revert xircom_cb to the "known good" old driver
#
%patch1160 -p1
#
# make the scsi timeout longer; 30 seconds is too short for big raid arrays
# with lots of large concurrent requests in flight
#
%patch1170 -p1
#
# make freevxfs autoload when doing mount -t vxfs /dev/foo /mnt/bar
#
%patch1180 -p1
#
# back out ewrk3 driver to the 2.4.2 version; all newer ones seem broken
#
%patch1190 -p1
#
# use the nmi interrupt for profiling; this allows the kernel profiler
# to profile even with interrupts disabled. Note: you have to specify the
# nmi watchdog as now as well for profiling to work:
# vmlinuz profile=1 nmi_watchdog=1
#
%patch1200 -p1
#
# allow more unnamed mounts by borrowing old, unused major devices
# This is needed if you want more than 255 NFS mounts; some people use the
# "one mount per user" automount setup and they need this if they have more
# than 255 users.
#
%patch1210 -p1
#
# add important bugfixes from Sistina's LVM-1.0.3
#
%patch1250 -p1
# add atomic, non-buggy pvmove to LVM...
%patch1251 -p1
%patch1252 -p1
# ...and add mempool, which the new LVM bits require
%patch1253 -p1
# Any other local fixes for LVM not related to pvmove:
%patch1254 -p1
# LVM atomic snapshot patch: quiesce the filesystem automatically when
# taking snapshots.
%patch1255 -p1
#
# Gamepad (all kbds and mice were affected, but we kludged arount it in hplug)
# autoload the proper modules
%patch1261 -p1
#
# add ethtool ioctl support to more network drivers
#
%patch1270 -p1
#
# new tigon3 driver for the broadcom 5700 chipset gigabit ethernet series
#
%patch1280 -p0
#
# updated nic drivers (eepro100/sis)
#
%patch1300 -p1
#
# updated megaraid driver to version 1.18a
#
%patch1310 -p1
#
# Several IDE driver updates
#
%patch1320 -p1
#
# add some devices to the scsi whitelist for multi-lun scanning
#
%patch1330 -p1
#
# allow ioctls to lun0 even if there's no lun0 (needed for some FC kit)
#
%patch1340 -p1
#
# ips ServerRAID driver 4.90
#
%patch1350 -p1
#
# oops when pl2303 services Visor and gets unplugged; fix from maintainer
%patch1360 -p1
#
# add 32 bit uid stupport to process accounting
#
%patch1370 -p1
# 
# some broken and defective applications assume that they can fstat() on a
# pipe and meaningful interpret the value of i_size. Apparently the
# arbitrary value 2.2 put there was good enough so we try to emulate that,
# since we prefer to keep compatibility within the RHL 7.x series. This is
# a gross hack that will go away as soon as possible.
#
%patch1380 -p1
#
# IRIX seems to return 64 bit cookies for readdir. glibc uses the 64 bit
# getdents even for 32 bit readdir and then the 64 bit cookies goes awol.
# Work around this by truncating/rounding this in the kernel
#
%patch1390 -p1
#
# Updates to ext3
#
%patch1400 -p1
#
# recognize newer wacom USB tablets
#
%patch1410 -p1

# 
# Some bioses "forget" to restore pci config space properly on resume;
# the following patch helps them a bit with this
#
%patch1420 -p1

#
# Add some extra PCI ID's to the aacraid driver
#
%patch1430 -p1

#
# the loopback device leaked file references
#
%patch1440 -p1

#
# Add an orinoco_old_cs driver (the 2.4.9 orinoco_cs driver)
# since the new one doesn't like one brand of cards
#
%patch1450 -p1

# ide-tape bites back (bugs 36628, 62267)
%patch2140 -p1


#
# Patches 5000 to 6000 are reserved for new drivers
#
# generic drivers/addon infrastructure
%patch5000 -p1
# (ugly) driver for the Dell megarac remote access cards
%patch5010 -p1
# Broadcom BCM5700/5701 Gigabit driver 
%patch5020 -p1
%patch5021 -p1
# wvlan_cs driver
%patch5030 -p1
%patch5031 -p1
# ECC reporting module
%patch5050 -p1
# alternate aironet driver
%patch5070 -p1
# IBM MXT memory compression support
#%patch5080 -p1
# fixes / updates to the MXT driver
#%patch5081 -p1
#%patch5082 -p1
# Broadcom 5820 driver
%patch5090 -p1
%patch5091 -p1
%patch5092 -p1
%patch5093 -p1
%patch5094 -p1
# iSCSI driver
%patch5120 -p1
# Intel e1000 driver
%patch5130 -p1
# Intel e100 driver
%patch5140 -p1
# add missing avma1_cs driver
%patch5170 -p1
# add tulip_old driver (2.4.3 version)
%patch5180 -p1
# cipe 1.4.5
%patch5190 -p1
%patch5191 -p1
%patch5192 -p1
# LM-Sensors
%patch5200 -p1
# qla2x00
%patch5210 -p1
# AEP SSL Accelerator card
%patch5220 -p1
# bridging firewall driver
%patch5230 -p1

#
# Patches 5800 to 6000 are the HA/IPVS patches
#
#%patch5800 -p1
#%patch5810 -p1
#%patch5820 -p1
%patch5830 -p1

#
# Patches 6000 and later are reserved for %if {something} patches
#


# ibcs
# NOTE: IBCS is not supported, might not work at all 
# and might go away at any time.
%if "%{ibcs}" == "1"
%ifarch %{all_x86}
%patch6000 -p1
%endif
%endif



# debugging patches
# extra sanitychecks in bufferhandling
#%if %{debugging}
#%patch7000 -p1
#%patch7030 -p1
#%patch7040 -p1
## Disable an smb debugging check which conflicts with slab poisoning
#%patch7050 -p1
#%endif



#
# final stuff
#

#
# lots of small fixes to warnings and other silly bugs
#
%patch10010 -p1

# several small tweaks
%patch10020 -p1

# aio - x86 only for the moment
%if "%{aio}" == "1"
%patch10100 -p1
%endif

# GRRRR
%ifarch %{all_arm}
# Put back drivers/serial and drivers/l3
%patch244 -p1
%endif
%ifarch sh
# Put back drivers/maple
%patch262 -p1
%endif
%ifarch ia64
%patch109 -p1
%patch111 -p1
%endif

%endif # redhat_patches

%if "%{redhatpatches}" == "0"

####
# Nando's patch collection
####

# enable CAP_SETPCAP capability on init
%patch20000 -p1

# preemptible kernel
%patch20004 -p1

# low latency patch
%patch20001 -p1

# Read Latency2
%patch20045 -p1

# Desktop Tuning 1
%patch20046 -p1

# Variable HZ setting:
%patch20047 -p1

# Desktop Tuning 2:
%patch20048 -p1

# ACPI: 2.4.22-pre includes most of the acpi patch
# not needed for 2.4.22 final
# %patch20007 -p1

# alsa rtc patch
%patch20072 -p1

# drm updates from the latest redhat kernel
# no longer necessary in 2.4.23-test5, all
# chunks appear to be reversed?
# %patch20073 -p1

# drm low latency patch
%patch20002 -p1

# speedup for cdrom audio extraction
%patch20074 -p1

# i2c 2.8.1
%patch20075 -p1
# lm_sensors 2.8.1
%patch20076 -p1
# extra i2c related patches
%patch20077 -p1
%patch20078 -p1
%patch20079 -p1
%patch20080 -p1
%patch20081 -p1
%patch20082 -p1
%patch20083 -p1
%patch20084 -p1
%patch20085 -p1
%patch20086 -p1
%patch20087 -p1
%patch20088 -p1
%patch20089 -p1
%patch20090 -p1
%patch20091 -p1

# nfs patches
%patch20100 -p1
%patch20101 -p1
%patch20102 -p1
%patch20103 -p1
%patch20104 -p1
%patch20105 -p1
%patch20106 -p1
%patch20107 -p1
%patch20108 -p1
%patch20109 -p1

# fix compilation of sk98lin (unresolved symbol)
# does not patch 2.4.23-test5
%patch20150 -p1

# fixes for unicorn usb drivers
# from: http://www.bewan.com/bewan/drivers/bapst-0.6.1.tar.gz
%patch20160 -p0

# fix for building airo driver
%patch20170 -p1

# fix for redefined symbol due to kernel version (remove in 2.4.23 final)
%patch20180 -p1 

#### Additional drivers and fixes from RedHat patches ####

# wvlan_cs driver
%patch5030 -p1

# add an orinoco_old_cs driver (the 2.4.9 orinoco_cs driver)
# since the new one doesn't like one brand of cards
%patch1450 -p1

# laptop battery monitor improvements for Gericom / Advent 7006 laptops
%patch2420 -p1

# accelerated crypto support

# generic drivers/addon infrastructure
%patch5001 -p1 

# (ugly) driver for the Dell megarac remote access cards
%patch5010 -p1

# broadcom 5820 driver (requested on planetccrma list)
%patch5090 -p1
%patch5091 -p1
%patch5092 -p1
%patch5093 -p1
%patch5094 -p1

# iSCSI driver
%patch5120 -p1

# cipe 1.4.5 (requested on planetccrma list)
%patch5190 -p1
%patch5191 -p1
%patch5192 -p1

# qla2x00
%patch5210 -p1

# AEP SSL Accelerator card
%patch5220 -p1

# feral qlogic driver patches
%patch2401 -p1
%patch2410 -p1

# ECC reporting module
%patch5050 -p1

# Backport of the 2.5 EDD feature to find the boot device (used for lilo, etc)
# %patch661 -p1
# %patch662 -p1

%endif


# END OF PATCH APPLICATIONS

chmod +x arch/sparc*/kernel/check_asm.sh

mkdir configs
%ifarch %{all_x86}
cp -fv $RPM_SOURCE_DIR/kernel-%{kversion}-i?86*.config configs
cp -fv $RPM_SOURCE_DIR/kernel-%{kversion}-athlon*.config configs
cp -fv $RPM_SOURCE_DIR/kernel-%{kversion}-x86_64*.config configs
%else
%ifarch sparc sparc64
cp -fv $RPM_SOURCE_DIR/kernel-%{kversion}-sparc*.config configs
%else
%ifarch %{all_ppc}
cp -fv $RPM_SOURCE_DIR/kernel-%{kversion}-ppc*.config configs
%else
%ifarch %{all_arm}

cp -fv $RPM_SOURCE_DIR/kernel-%{kversion}-arm*.config configs
%else
cp -fv $RPM_SOURCE_DIR/kernel-%{kversion}-%{_target_cpu}*.config configs
%endif
%endif
%endif
%endif

cp %{SOURCE100} include/linux/

# make sure the kernel has the sublevel we know it has...
perl -p -i -e "s/^SUBLEVEL.*/SUBLEVEL = %{sublevel}/" Makefile

# get rid of unwanted files
find . -name "*.orig" -exec rm -fv {} \;
find . -name "*~" -exec rm -fv {} \;

chmod 755 arch/*/kernel/check_asm.sh

###
### build
###
%build

# df has a few peculiarities we have to deal with here:
#  o  If it can't find the partition, it calls it "-"
#  o  If the device name is too long (e.g. loopback file)
#     it puts it on a separate line from the data
partitionof ()
{
    # find the directory that exists
    if [ -d "$1" ] ; then
	df "$1" | awk '/^\// {print $1}'
    else
	partitionof $(dirname /$1)
    fi
}
spaceof ()
{
    echo $(($(df $(partitionof $1) | awk '/^\// {if ($4) {print $4}}
              /^[ \t]/ {print $3}') / 1024))
}
# If df exists and df understands the current root directory, check
# space guestimates.  (df may not grok / for some chrooted build envs)
if [ -x /bin/df ] && [ $(partitionof /) != - ] ; then
    if [ "$(partitionof $RPM_BUILD_ROOT)" = "$(partitionof $RPM_BUILD_DIR)" ] ; then
	# The build root and build dir are on one partition; need to check
	# them together
	[ "$(($(spaceof $RPM_BUILD_ROOT)))" -lt \
	  "$((%{RPM_BUILD_ROOT_space} + %{RPM_BUILD_DIR_space}))" ] && {
	    echo "insufficient free disk space to build" >&2 ;
	    exit 1 ;
	}
    else
	# The build root and build dir are on separate partitions; need to
	# check them separately
	[ "$(spaceof $RPM_BUILD_ROOT)" -lt "%{RPM_BUILD_ROOT_space}" ] && {
	    echo "build root $RPM_BUILD_ROOT has insufficient free disk space" >&2 ;
	    exit 1 ;
	}
	[ "$(spaceof $RPM_BUILD_DIR)" -lt "%{RPM_BUILD_DIR_space}" ] && {
	    echo "build dir $RPM_BUILD_DIR has insufficient free disk space" >&2 ;
	    exit 1 ;
	}
    fi
fi

# if RPM_BUILD_NCPUS unset, set it
if [ -z "$RPM_BUILD_NCPUS" ] ; then
    RPM_BUILD_NCPUS=`egrep -c "^cpu[0-9]+" /proc/stat || :` 
    if [ $RPM_BUILD_NCPUS -eq 0 ] ; then
	RPM_BUILD_NCPUS=1
    fi
    if [ $RPM_BUILD_NCPUS -gt 8 ] ; then
	RPM_BUILD_NCPUS=8
    fi
fi


cd linux-%{version}

cat > genkey <<EOF
%pubring `pwd`/kernel.pub
%secring `pwd`/kernel.sec
Key-Type: DSA
Key-Length: 512
Name-Real: Red Hat, Inc.
Name-Comment: Kernel Module GPG key
%commit
EOF

AddPatches () {
    # $1 is BOOT/bigmem/debug/foo
    case "$1" in
    debug) patch -p1 < $RPM_SOURCE_DIR/linux-2.4.7-ikd.patch ;;
    esac
    # remove any backup files that were created
    find . -name "*.orig" -exec rm -fv {} \;
    find . -name "*~" -exec rm -fv {} \;
}

RemovePatches () {
    # $1 is BOOT/bigmem/debug/foo
    case "$1" in
    debug) patch -p1 -R < $RPM_SOURCE_DIR/linux-2.4.7-ikd.patch ;;
    esac
    # remove any backup files that were created
    find . -name "*.orig" -exec rm -fv {} \;
    find . -name "*~" -exec rm -fv {} \;
}

DependKernel() {
    # is this a special kernel we want to build?
    if [ -n "$2" ] ; then
	Config=$1-$2
	KernelVer=%{version}-%{release}$2
	echo MAKE DEPEND FOR $2 $1 KERNEL...
    else
	Config=$1%{dashtargetboard}
	KernelVer=%{version}-%{release}
	echo MAKE DEPEND FOR up $1 KERNEL...
    fi
    make -s mrproper
# We used to copy the config file to arch/.../defconfig, but for some time now
# the Configure script has been smart enough to override this with the
# config file found in configs/kernel-%{kversion}-${config}.config when it
# finds a valid /boot/kernel.h file.  As a result, making an RPM on a
# machine that has a valid kernel.h file will result in scripts/Configure
# overriding our config entries with whatever it thinks is appropriate
# (aka, if you try an i386 build on a machine with an i686 smp kernel.h file
# then you will get an i686 smp kernel in an i386 package).  So, instead we
# put our config file in .config, which is considered the ultimate source
# of default config information by make oldconfig.  Also, copy the config
# files out of the configs directory instead of the RPM_SOURCE_DIR.  It
# doesn't make any sense to put them in there and then not use them,
# especially when we could have a patch that modifies the config files
# as part of the bigmem patch set (or any other patch, it just makes
# us more flexible to use the configs from the configs directory).  Finally,
# since make mrproper wants to wipe out .config files, we move our mrproper
# up before we copy the config files around.
    cp configs/kernel-%{kversion}-$Config.config .config
    # make sure EXTRAVERSION says what we want it to say
    perl -p -i -e "s/^EXTRAVERSION.*/EXTRAVERSION = -%{release}$2/" Makefile
%ifarch sparc sparc64     
    make -s ARCH=$1 oldconfig_nonint
    make -s ARCH=$1 dep
    make -s ARCH=$1 include/linux/version.h 
%else
    if [ "$2" = "uml" ] ; then
    	make -s ARCH=um oldconfig_nonint
    else # We do it twice, because make oldconfig tends to get stuff wrong.
    	make -s oldconfig_nonint
    	make -s oldconfig_nonint
    fi
    make -s -j $RPM_BUILD_NCPUS dep
    make -s include/linux/version.h 
%endif
}

BuildKernel() {
    if [ -n "$1" ] ; then
	Config=%{_target_cpu}-$1
	KernelVer=%{version}-%{release}$1
	DependKernel %{_target_cpu} $1
	echo BUILDING A KERNEL FOR $1 %{_target_cpu}...
    else
	Config=%{_target_cpu}%{dashtargetboard}
	KernelVer=%{version}-%{release}
	DependKernel %{_target_cpu}
	echo BUILDING THE NORMAL KERNEL for %{_target_cpu}...
    fi

%ifarch %{all_x86}
    if [ "$1" = "uml" ] ; then
    	make -s -j $RPM_BUILD_NCPUS ARCH=um linux 
    else
    	make -s -j $RPM_BUILD_NCPUS %{gccversion} CFLAGS_KERNEL="-Wno-unused" bzImage 
    fi
%else
%ifarch %{all_ppc} %{all_mips}
    make -s -j $RPM_BUILD_NCPUS vmlinux
%else
%ifarch s390 s390x
    make -s -j $RPM_BUILD_NCPUS image
%else
%ifarch %{all_arm} sh
    make -s -j $RPM_BUILD_NCPUS zImage
%else
    make -s -j $RPM_BUILD_NCPUS boot 
%endif
%endif
%endif
%endif
    if [ "$1" = "uml" ] ; then
    	make -s -j $RPM_BUILD_NCPUS ARCH=um modules
    else
    	make -s -j $RPM_BUILD_NCPUS %{gccversion} CFLAGS_KERNEL="-Wno-unused" modules || exit 1
    fi
    # first make sure we are not loosing any .ver files to make mrporper's
    # removal of zero sized files.
    find include/linux/modules -size 0 | while read file ; do \
	echo > $file
    done
    # Start installing stuff
    mkdir -p $RPM_BUILD_ROOT/boot
    install -m 644 System.map $RPM_BUILD_ROOT/boot/System.map-$KernelVer
    install -m 644 $RPM_SOURCE_DIR/module-info $RPM_BUILD_ROOT/boot/module-info-$KernelVer
    install -m 644 configs/kernel-%{kversion}-$Config.config $RPM_BUILD_ROOT/boot/config-$KernelVer
    mkdir -p $RPM_BUILD_ROOT/dev/shm
%ifarch ia64
    %{_mystrip} --strip-debug vmlinux
%endif
%ifarch %{all_x86}
    if [ "$1" = "uml" ] ; then
    	cp linux $RPM_BUILD_ROOT/boot/vmlinuz-$KernelVer
    else
	%ifnarch x86_64
	    	cp arch/i386/boot/bzImage $RPM_BUILD_ROOT/boot/vmlinuz-$KernelVer
	%else
	    	cp arch/x86_64/boot/bzImage $RPM_BUILD_ROOT/boot/vmlinuz-$KernelVer
	%endif
    	cp vmlinux $RPM_BUILD_ROOT/boot/vmlinux-$KernelVer
    fi
%else
%ifarch %{all_arm}
    cp arch/arm/boot/zImage $RPM_BUILD_ROOT/boot/vmlinuz-$KernelVer
    cp vmlinux $RPM_BUILD_ROOT/boot/vmlinux-$KernelVer
%else
%ifarch sh
    cp arch/sh/boot/zImage $RPM_BUILD_ROOT/boot/vmlinuz-$KernelVer
    cp vmlinux $RPM_BUILD_ROOT/boot/vmlinux-$KernelVer
%else
%ifarch ia64
    gzip -cfv vmlinux > vmlinuz
    mkdir -p $RPM_BUILD_ROOT/boot/efi/redhat
    install -m 755 vmlinux $RPM_BUILD_ROOT/boot/efi/redhat/vmlinux-$KernelVer
    install -m 755 vmlinuz $RPM_BUILD_ROOT/boot/efi/redhat/vmlinuz-$KernelVer
    ln -s efi/vmlinux-$KernelVer $RPM_BUILD_ROOT/boot/vmlinux-$KernelVer
    ln -s efi/vmlinuz-$KernelVer $RPM_BUILD_ROOT/boot/vmlinuz-$KernelVer
%else
%ifarch s390 s390x
    install -m 755 arch/%{_target_cpu}/boot/image $RPM_BUILD_ROOT/boot/vmlinuz-$KernelVer
    install -m 755 arch/%{_target_cpu}/boot/*.boot $RPM_BUILD_ROOT/boot/
%else
%ifnarch %{all_ppc}
    gzip -cfv vmlinux > vmlinuz
    install -m 644 vmlinuz $RPM_BUILD_ROOT/boot/vmlinuz-$KernelVer
%endif
%endif
    install -m 755 vmlinux $RPM_BUILD_ROOT/boot/vmlinux-$KernelVer
%endif
%endif
%endif
%endif
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer
    make -s INSTALL_MOD_PATH=$RPM_BUILD_ROOT modules_install KERNELRELEASE=$KernelVer
    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/modules.*

%if "%{redhatpatches}" == "1"
    install -m 755 ulib/libredhat-kernel.so.1 $RPM_BUILD_ROOT/lib/kernel/$KernelVer/
%endif

%ifarch ia64 alpha
    %{_mystrip} --strip-debug `find $RPM_BUILD_ROOT/lib/modules/$KernelVer -type f` || :
%endif

# remove legacy pcmcia symlink that's no longer useful
%ifarch %{nptlarchs}
    rm -rf $RPM_BUILD_ROOT/lib/modules/$KernelVer/pcmcia
%endif

}

SaveHeaders() {
    echo "SAVING HEADERS for $1 $2"
    # deal with the kernel headers that are version specific
    mkdir -p $RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}/savedheaders/$2/$1
    install -m 644 include/linux/autoconf.h \
	$RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}/savedheaders/$2/$1/autoconf.h
    install -m 644 include/linux/version.h \
	$RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}/savedheaders/$2/$1/version.h
    mv include/linux/modules \
	$RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}/savedheaders/$2/$1/
    echo $2 $1 ../../savedheaders/$2/$1/ >> $RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}/savedheaders/list
}

###
# DO it...
###

rm -rf $RPM_BUILD_ROOT

%if %{buildjensen}
BuildKernel jensen
%endif

%if %{buildtape}
BuildKernel tape
SaveHeaders tape %{_target_cpu}
%endif

%if %{buildBOOTtape}
BuildKernel BOOTtape
SaveHeaders BOOTtape %{_target_cpu}
%endif

%if %{buildUML}
BuildKernel uml
SaveHeaders uml i686
%endif

%if %{builddebug}
BuildKernel debug
SaveHeaders debug %{_target_cpu}
%endif

%if %{buildbigmem}
BuildKernel bigmem
SaveHeaders bigmem %{_target_cpu}
%endif

%if %{buildsmp}
BuildKernel smp
SaveHeaders smp %{_target_cpu}
%endif

%if %{buildBOOT}
BuildKernel BOOT
SaveHeaders BOOT %{_target_cpu}
%endif

%ifarch i386
DependKernel i586
SaveHeaders up i586
DependKernel i686
SaveHeaders up i686
DependKernel athlon
SaveHeaders up athlon
%endif
%ifarch sparc
DependKernel sparc64
SaveHeaders up sparc64
%endif

%ifarch i386 
DependKernel i586 smp
SaveHeaders smp i586
DependKernel i686 smp
SaveHeaders smp i686
%if "%{makedependall}" == "1"
DependKernel i686 bigmem
SaveHeaders bigmem i686
DependKernel i686 debug
SaveHeaders debug i686
%endif
DependKernel athlon smp
SaveHeaders smp athlon
%endif
%ifarch sparc
DependKernel sparc64 smp
SaveHeaders smp sparc64
%endif

# UNIPROCESSOR KERNEL
%if %{buildup}
BuildKernel
%ifarch i386 alpha sparc ia64 s390 s390x %{all_ppc} %{all_arm} sh %{all_mips}
SaveHeaders up %{_target_cpu}
%endif
%endif



###
### install
###

%install

cd linux-%{version}
mkdir -p $RPM_BUILD_ROOT/{boot,sbin}
%ifarch ppciseries
install -m 755 $RPM_SOURCE_DIR/installkernel.iSeries $RPM_BUILD_ROOT/sbin/installkernel
install -m 755 $RPM_SOURCE_DIR/installcmdline.iSeries $RPM_BUILD_ROOT/sbin/installcmdline
%endif

for i in $RPM_BUILD_ROOT/lib/modules/*; do
  rm -f $i/build 
  ln -sf ../../../usr/src/linux-%{KVERREL} $i/build
done

%ifarch athlon i586 i686 sparc64
# these don't need much
rm -rf $RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}/savedheaders
exit 0
%endif

mkdir -p $RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}
rm -f drivers/net/hamradio/soundmodem/gentbl scripts/mkdep
tar cf - . | tar xf - -C $RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}
perl -p -i -e "s/^EXTRAVERSION.*/EXTRAVERSION = -%{release}custom/" $RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}/Makefile
ln -sf linux-%{KVERREL} $RPM_BUILD_ROOT/usr/src/linux
install -m 644 %{SOURCE10}  $RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}

%ifarch sparc
ln -s ../src/linux/include/asm-sparc $RPM_BUILD_ROOT/usr/include/asm-sparc
ln -s ../src/linux/include/asm-sparc64 $RPM_BUILD_ROOT/usr/include/asm-sparc64
mkdir $RPM_BUILD_ROOT/usr/include/asm
cp -a $RPM_SOURCE_DIR/kernel-2.4-BuildASM.sh $RPM_BUILD_ROOT/usr/src/linux/include/asm-sparc/BuildASM
$RPM_BUILD_ROOT/usr/include/asm-sparc/BuildASM $RPM_BUILD_ROOT/usr/include
%endif

#clean up the destination
make -s mrproper -C $RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}
cp configs/kernel-%{kversion}-%{_target_cpu}%{dashtargetboard}.config $RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}/.config
make -s oldconfig_nonint -C $RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}
make -s symlinks -C $RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}
make -s include/linux/version.h -C $RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}

#this generates modversions info which we want to include and we may as
#well include the depends stuff as well, after we fix the paths
make -s depend -C $RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}
find $RPM_BUILD_ROOT/usr/src/linux-%{KVERREL} -name ".*depend" | \
while read file ; do
    mv $file $file.old
    sed -e "s|[^ ]*\(/usr/src/linux\)|\1|g" < $file.old > $file
    rm -f $file.old
done

# Try to put some smarter autoconf.h and version.h files in place
pushd $RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}/include/linux ; {
rm -rf modules modversions.h autoconf.h version.h
cat > modversions.h <<EOF
#ifndef _LINUX_MODVERSIONS_H
#define _LINUX_MODVERSIONS_H
#include <linux/rhconfig.h>
#include <linux/modsetver.h>
EOF
echo '#include <linux/rhconfig.h>' > autoconf.h
list=`find ../../savedheaders/* -name '*.ver' -exec basename '{}' \; | sort`
mkdir modules
for l in $list; do
    sed 's,$,modules/'$l, ../../savedheaders/list | awk -f %{SOURCE17} > modules/$l
    touch -r modules/$l modules/`basename $l .ver`.stamp
    echo '#include <linux/modules/'$l'>' >> modversions.h
done
echo '#endif' >> modversions.h
sed 's,$,autoconf.h,' ../../savedheaders/list | awk -f %{SOURCE16} >> autoconf.h
install -m 644 %{SOURCE15} rhconfig.h
echo "#include <linux/rhconfig.h>" >> version.h
keyword=if
for i in smp BOOT BOOTsmp bigmem debug tape BOOTtape up ; do
# When we build in an i386, we don't have an bigmem header directory
# in savedheaders/i386/bigmem.  We also don't have a BOOT directory
# anywhere except in savedheaders/i386.  So, we need to use this method
# of determining if a kernel version string needs to be included in the
# version.h file
    verh=`echo ../../savedheaders/*/$i/version.h | awk ' { print $1 } '`
    if [ -n "$verh" -a -f "$verh" ]; then
	if [ "$i" = up ]; then
	    if [ "$keyword" = if ]; then
		echo "#if 0" >> version.h
	    fi
  	    echo "#else" >> version.h
	else
	    echo "#$keyword defined(__module__$i)" >> version.h
	    keyword=elif
	fi
	grep UTS_RELEASE $verh >> version.h
    fi
done
echo "#endif" >> version.h
if [ -f ../../savedheaders/%{_target_cpu}/up/version.h ] ; then
    # keep to a standard normally
    HEADER_FILE=../../savedheaders/%{_target_cpu}/up/version.h
else
    # test build not including uniprocessor, must get info from somewhere
    HEADER_FILE=$(ls ../../savedheaders/%{_target_cpu}/*/version.h | head -1)
fi
grep -v UTS_RELEASE $HEADER_FILE >> version.h
rm -rf ../../savedheaders
} ; popd
touch $RPM_BUILD_ROOT/boot/kernel.h-%{kversion}

rm -f $RPM_BUILD_ROOT/usr/include/linux

for i in $RPM_BUILD_ROOT/lib/modules/*; do
  rm -f $i/modules.*
done

rm -rf $RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}/savedheaders

# fix up the tmp_include_depends file wrt the buildroot
perl -p -i -e "s|$RPM_BUILD_ROOT||g" $RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}/tmp_include_depends

###
### clean
###

%clean
rm -rf $RPM_BUILD_ROOT

###
### scripts
###

# do this for upgrades...in case the old modules get removed we have
# loopback in the kernel so that mkinitrd will work.
%pre 
/sbin/modprobe loop 2> /dev/null > /dev/null  || :
exit 0

%pre smp
/sbin/modprobe loop 2> /dev/null > /dev/null  || :
exit 0

%pre bigmem
/sbin/modprobe loop 2> /dev/null > /dev/null  || :
exit 0

%pre debug
/sbin/modprobe loop 2> /dev/null > /dev/null  || :
exit 0

%post 
cd /boot
%ifnarch ia64 %{all_ppc}
ln -sf vmlinuz-%{KVERREL} vmlinuz
%endif
%ifarch %{all_ppc}
ln -sf vmlinux-%{KVERREL} vmlinux
%endif
ln -sf System.map-%{KVERREL} System.map
ln -sf module-info-%{KVERREL} module-info
[ -x /usr/sbin/module_upgrade ] && /usr/sbin/module_upgrade
[ -x /sbin/mkkerneldoth ] && /sbin/mkkerneldoth
if [ -x /sbin/new-kernel-pkg ] ; then
        /sbin/new-kernel-pkg --mkinitrd --depmod --install %{KVERREL}
fi

%post smp
cd /boot
%ifnarch ia64 %{all_ppc}
ln -sf vmlinuz-%{KVERREL}smp vmlinuz
%endif
%ifarch %{all_ppc}
ln -sf vmlinux-%{KVERREL}smp vmlinux
%endif
ln -sf System.map-%{KVERREL}smp System.map
ln -sf module-info-%{KVERREL}smp module-info
[ -x /usr/sbin/module_upgrade ] && /usr/sbin/module_upgrade
[ -x /sbin/mkkerneldoth ] && /sbin/mkkerneldoth
if [ -x /sbin/new-kernel-pkg ] ; then
        /sbin/new-kernel-pkg --mkinitrd --depmod --install %{KVERREL}smp
fi

%post bigmem
[ -x /usr/sbin/module_upgrade ] && /usr/sbin/module_upgrade
[ -x /sbin/mkkerneldoth ] && /sbin/mkkerneldoth
if [ -x /sbin/new-kernel-pkg ] ; then
        /sbin/new-kernel-pkg --mkinitrd --depmod --install %{KVERREL}bigmem
fi

%post debug
[ -x /usr/sbin/module_upgrade ] && /usr/sbin/module_upgrade
[ -x /sbin/mkkerneldoth ] && /sbin/mkkerneldoth
if [ -x /sbin/new-kernel-pkg ] ; then
        /sbin/new-kernel-pkg --mkinitrd --depmod --install %{KVERREL}debug
fi

%post jensen
[ -x /usr/sbin/module_upgrade ] && /usr/sbin/module_upgrade
[ -x /sbin/mkkerneldoth ] && /sbin/mkkerneldoth
if [ -x /sbin/new-kernel-pkg ] ; then
        /sbin/new-kernel-pkg --mkinitrd --depmod --install %{KVERREL}jensen
fi

%post tape
[ -x /usr/sbin/module_upgrade ] && /usr/sbin/module_upgrade
[ -x /sbin/mkkerneldoth ] && /sbin/mkkerneldoth
if [ -x /sbin/new-kernel-pkg ] ; then
        /sbin/new-kernel-pkg --mkinitrd --depmod --install %{KVERREL}debug
fi


%ifnarch ia64
%post BOOT
[ -x /usr/sbin/module_upgrade ] && /usr/sbin/module_upgrade
[ -x /sbin/mkkerneldoth ] && /sbin/mkkerneldoth
if [ -x /sbin/new-kernel-pkg ] ; then
        /sbin/new-kernel-pkg --mkinitrd --depmod --install %{KVERREL}BOOT
fi

%endif

# Allow clean removal of modules directory
%preun 
/sbin/modprobe loop 2> /dev/null > /dev/null  || :
#rm -f /lib/modules/%{KVERREL}/modules.*
if [ -x /sbin/new-kernel-pkg ] ; then
 /sbin/new-kernel-pkg --rminitrd --rmmoddep --remove %{KVERREL}
fi


%preun smp
/sbin/modprobe loop 2> /dev/null > /dev/null  || :
rm -f /lib/modules/%{KVERREL}smp/modules.*
if [ -x /sbin/new-kernel-pkg ] ; then
 /sbin/new-kernel-pkg --rminitrd --rmmoddep --remove %{KVERREL}smp
fi


%preun bigmem
/sbin/modprobe loop 2> /dev/null > /dev/null  || :
rm -f /lib/modules/%{KVERREL}bigmem/modules.*
if [ -x /sbin/new-kernel-pkg ] ; then
 /sbin/new-kernel-pkg --rminitrd --rmmoddep --remove %{KVERREL}bigmem
fi


%preun debug
/sbin/modprobe loop 2> /dev/null > /dev/null  || :
rm -f /lib/modules/%{KVERREL}debug/modules.*
if [ -x /sbin/new-kernel-pkg ] ; then
 /sbin/new-kernel-pkg --rminitrd --rmmoddep --remove %{KVERREL}debug
fi

%preun BOOT
/sbin/modprobe loop 2> /dev/null > /dev/null  || :
#rm -f /lib/modules/%{KVERREL}BOOT/modules.*
if [ -x /sbin/new-kernel-pkg ] ; then
 /sbin/new-kernel-pkg --rminitrd --rmmoddep --remove %{KVERREL}BOOT
fi


%preun jensen
/sbin/modprobe loop 2> /dev/null > /dev/null  || :
#rm -f /lib/modules/%{KVERREL}jensen/modules.*

%preun tape
/sbin/modprobe loop 2> /dev/null > /dev/null   || :
#rm -f /lib/modules/%{KVERREL}tape/modules.*

%preun BOOTtape
/sbin/modprobe loop 2> /dev/null > /dev/null || :
#rm -f /lib/modules/%{KVERREL}BOOTtape/modules.*

# We need this here because we don't prereq kudzu; it could be
# installed after the kernel
%triggerin -- kudzu
[ -x /usr/sbin/module_upgrade ] && /usr/sbin/module_upgrade || :

%triggerin smp -- kudzu
[ -x /usr/sbin/module_upgrade ] && /usr/sbin/module_upgrade || :

%triggerin bigmem -- kudzu
[ -x /usr/sbin/module_upgrade ] && /usr/sbin/module_upgrade || :

%triggerin BOOT -- kudzu
[ -x /usr/sbin/module_upgrade ] && /usr/sbin/module_upgrade || :

%triggerin jensen -- kudzu
[ -x /usr/sbin/module_upgrade ] && /usr/sbin/module_upgrade || :


# Old kernel-headers packages owned include symlinks; new
# ones just make them so that we can have multiple kernel-headers
# packages installed.

%triggerpostun source -- kernel-headers < 2.2.16
cd /usr/src
rm -f %{kslnk}
ln -snf linux-%{KVERREL} %{kslnk}
exit 0

%post source
cd /usr/src
rm -f %{kslnk}
ln -snf linux-%{KVERREL} %{kslnk}

%postun source
if [ -L /usr/src/%{kslnk} ]; then 
    if [ -L /usr/src/%{kslnk} -a `ls -ld /usr/src/%{kslnk} 2>/dev/null| awk '{ print $11 }'` = "linux-%{KVERREL}" ]; then
	[ $1 = 0 ] && rm -f /usr/src/%{kslnk}
    fi
fi
exit 0

###
### file lists
###

%if %{buildup}
%files 
%defattr(-,root,root)
/boot/%{kernel_glob}
%ifarch ia64
/boot/efi/redhat/%{kernel_glob}
%endif
%ifarch s390 s390x
/boot/*.boot
%endif
/boot/module-info-%{KVERREL}
/boot/System.map-%{KVERREL}
/boot/config-%{KVERREL}
%ifarch ppciseries
%config /sbin/installcmdline
%endif
%dir /lib/modules
%dir /dev/shm
/lib/modules/%{KVERREL}
%if "%{redhatpatches}" == "1"
/lib/kernel/%{KVERREL}
%endif
%endif

%if %{buildsmp}
%ifnarch i386 s390 s390x
%files smp
%defattr(-,root,root)
/boot/%{kernel_glob}smp
%ifarch ia64
/boot/efi/redhat/%{kernel_glob}smp
%endif
/boot/module-info-%{KVERREL}smp
/boot/System.map-%{KVERREL}smp
/boot/config-%{KVERREL}smp
%ifarch ppciseries
%config /sbin/installcmdline
%endif
%dir /lib/modules
%dir /dev/shm
/lib/modules/%{KVERREL}smp
%if "%{redhatpatches}" == "1"
/lib/kernel/%{KVERREL}smp
%endif

%endif
%endif

%if %{buildbigmem}
%files bigmem
%defattr(-,root,root)
/boot/%{kernel_glob}bigmem
/boot/module-info-%{KVERREL}bigmem
/boot/System.map-%{KVERREL}bigmem
/boot/config-%{KVERREL}bigmem
%dir /lib/modules
%dir /dev/shm
/lib/modules/%{KVERREL}bigmem
%if "%{redhatpatches}" == "1"
/lib/kernel/%{KVERREL}bigmem
%endif
%endif

%if %{buildUML}
%files uml
%defattr(-,root,root)
/boot/%{debug_kernel_glob}uml
/boot/module-info-%{KVERREL}uml
/boot/System.map-%{KVERREL}uml
/boot/config-%{KVERREL}uml
%dir /lib/modules
%dir /dev/shm
/lib/modules/%{KVERREL}uml
%if "%{redhatpatches}" == "1"
/lib/kernel/%{KVERREL}uml
%endif
%endif

%if %{builddebug}
%files debug
%defattr(-,root,root)
/boot/%{debug_kernel_glob}debug
/boot/module-info-%{KVERREL}debug
/boot/System.map-%{KVERREL}debug
/boot/config-%{KVERREL}debug
%dir /lib/modules
%dir /dev/shm
/lib/modules/%{KVERREL}debug
%if "%{redhatpatches}" == "1"
/lib/kernel/%{KVERREL}debug
%endif
%endif

%if %{buildjensen}
%files jensen
%defattr(-,root,root)
/boot/%{kernel_glob}jensen
/boot/System.map-%{KVERREL}jensen
%dir /lib/modules
%dir /dev/shm
/lib/modules/%{KVERREL}jensen
%endif

%if %{buildtape}
%files tape
%defattr(-,root,root)
/boot/%{kernel_glob}tape
/boot/System.map-%{KVERREL}tape
/boot/config-%{KVERREL}tape
%ifarch s390 s390x
/boot/*.boot
%endif
%dir /lib/modules
%dir /dev/shm
/lib/modules/%{KVERREL}tape
%endif

%if %{buildBOOTtape}
%files BOOTtape
%defattr(-,root,root)
/boot/%{kernel_glob}BOOTtape
/boot/System.map-%{KVERREL}BOOTtape
/boot/config-%{KVERREL}BOOTtape
%dir /lib/modules
%dir /dev/shm
/lib/modules/%{KVERREL}BOOTtape
%endif

%if %{buildBOOT}
%files BOOT
%defattr(-,root,root)
/boot/%{kernel_glob}BOOT
/boot/System.map-%{KVERREL}BOOT
/boot/config-%{KVERREL}BOOT
%dir /lib/modules
%dir /dev/shm
/lib/modules/%{KVERREL}BOOT
%endif

%ifnarch i586 i686 sparc64 athlon
# START BASE ARCHES ONLY
%ifarch i386 alpha sparc ia64 s390 s390x %{all_ppc} %{all_arm} sh %{all_mips}

%files source
%defattr(-,root,root)
%dir /usr/src/linux-%{KVERREL}
/usr/src/linux-%{KVERREL}/COPYING*
/usr/src/linux-%{KVERREL}/CREDITS
/usr/src/linux-%{KVERREL}/Documentation
/usr/src/linux-%{KVERREL}/MAINTAINERS
/usr/src/linux-%{KVERREL}/Makefile
/usr/src/linux-%{KVERREL}/README
/usr/src/linux-%{KVERREL}/REPORTING-BUGS
/usr/src/linux-%{KVERREL}/Rules.make
/usr/src/linux-%{KVERREL}/arch
%ifarch sparc
/usr/src/linux-%{KVERREL}/arch/sparc64
%endif
/usr/src/linux-%{KVERREL}/drivers
/usr/src/linux-%{KVERREL}/crypto
/usr/src/linux-%{KVERREL}/fs
/usr/src/linux-%{KVERREL}/init
/usr/src/linux-%{KVERREL}/ipc
/usr/src/linux-%{KVERREL}/kernel
/usr/src/linux-%{KVERREL}/lib
/usr/src/linux-%{KVERREL}/mm
/usr/src/linux-%{KVERREL}/net
/usr/src/linux-%{KVERREL}/scripts
%ifarch %{all_x86}
%{?ibcs_1:/usr/src/linux-%{KVERREL}/abi}
%endif
%if "%{redhatpatches}" == "1"
/usr/src/linux-%{KVERREL}/ulib
%endif
/usr/src/linux-%{KVERREL}/configs
/usr/src/linux-%{KVERREL}/include
/usr/src/linux-%{KVERREL}/include/asm
%ifarch %{all_x86}
%{?ibcs_1:/usr/src/linux-%{KVERREL}/include/abi}
%endif
/usr/src/linux-%{KVERREL}/include/linux
/usr/src/linux-%{KVERREL}/include/net
/usr/src/linux-%{KVERREL}/include/pcmcia
/usr/src/linux-%{KVERREL}/include/scsi
/usr/src/linux-%{KVERREL}/include/video
%dir /usr/src/linux-%{KVERREL}/include
%dir /usr/src/linux-%{KVERREL}/arch
%ifarch alpha sparc
/usr/src/linux-%{KVERREL}/include/math-emu
%endif  

%files doc
%defattr(-,root,root)
%doc linux-%{version}/Documentation/*


%endif
# END BASE ARCHES ONLY
%endif


%changelog
* Sun Nov 30 2003 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.4.23-1.ll
- updated to 2.4.23!
* Fri Nov 21 2003 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.4.22-9.23rc3.ll
- updated to 2.4.23-rc3
* Wed Nov 19 2003 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.4.22-9.23rc2.ll
- updated to 2.4.23-rc2
* Mon Nov  9 2003 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.4.22-9.23rc1.ll
- added patches and flags for building on Fecora Core 1 (needs gcc32)
- updated to 2.4.23-rc1
- downloaded new set of NFS patches
- removed edd patch (patch661/662), seems to be there already
- lm_sensors 2.8.1 and i2c: see http://delvare.free.fr/i2c/
  generated new patch from lm_sensors 2.8.1 sources (patch20075)
  generated i2c patch from i2c 2.8.1 sources (patch20076)
- updated linux-2.4.22-addon.patch (drivers/Makefile reject)
- make oldconfig on i686 configuration
  AMI MegaRAID2 support (CONFIG_SCSI_MEGARAID2) [N/m/?] (NEW) m
  AMD 8111 SMBus 2.0 (CONFIG_I2C_AMD8111) [N/m/?] (NEW) m
  SiS 630/730 (CONFIG_I2C_SIS630) [N/m/?] (NEW) m
  SiS 645/961,645DX/961,735 (CONFIG_I2C_SIS645) [N/m/?] (NEW) m
  Analog Devices ADM1026 (CONFIG_SENSORS_ADM1026) [N/m/?] (NEW) m
  National Semiconductor LM85, Analog Devices ADM1027 (CONFIG_SENSORS_LM85) [N/m/?] (NEW) m
  SL811HS Alternate (x86, StrongARM, isosynchronous mode) (CONFIG_USB_SL811HS_ALT) [N/m/?] (NEW) m
  SL811HS (x86, StrongARM) support, old driver (CONFIG_USB_SL811HS) [N/m/?] (NEW) m
  USB W996[87]CF Camera support (CONFIG_USB_W9968CF) [N/m/?] (NEW) m
  Support for USB Gadgets (CONFIG_USB_GADGET) [N/y/?] (NEW) y
  NetChip 2280 support (CONFIG_USB_NET2280) [N/y/m/?] (NEW) m
  Gadget Zero (DEVELOPMENT) (CONFIG_USB_ZERO) [N/m/?] (NEW) m
  Ethernet Gadget (EXPERIMENTAL) (CONFIG_USB_ETH) [N/m/?] (NEW) m
- added additional i2c patches
  Basic I2C on Parallel Port (CONFIG_I2C_PPORT) [N/m/?] (NEW) m
  PCF on EPP port (CONFIG_I2C_PCFEPP) [N/m/?] (NEW) m
- I2C_DRIVERID_TDA9887 does not exist, eliminate reference from media-video patch
- added Patch20180, fix nsp32.c's redefinition of irqreturn_t due to kernel
  version mismatch (kernel version is stil 22 but sources are for 23-rc1)
- turned off W9968 support (just added), there is a missing ID number for it:
  `I2C_HW_SMBUS_W9968CF' undeclared
  USB W996[87]CF Camera support (CONFIG_USB_W9968CF) [N/m/?] (NEW) N

* Wed Oct  1 2003 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.4.22-8.ll
- updated to 2.4.23-pre6
- configuration options:
  The SCTP Protocol (EXPERIMENTAL) (CONFIG_IP_SCTP)=N
  AMD Opteron/Athlon64 on-CPU GART support (CONFIG_AGP_AMD_K8)=y
- as we name the kernel 2.4.22 we need an additional patch so that
  drivers/net/wireless/airo.c can compile (Patch20170)
    airo.c:207: redefinition of `PDE'
- updated nfs patches from http://www.fys.uio.no/~trondmy/src/2.4.22/,
  added one patch (Patch20080: linux-2.4.22-01-resends.dif)
* Mon Sep 22 2003 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.4.22-7.ll
- updated to 2.4.23-rc5
- tweaked low latency patch (one chunk failing in fs/inode.c)
- tweaked alsa rtc patch (failing Makefile chunk)
- tweaked sk98lin compile patch
- configuration changes:
  (only on SMP configurations)
  Maximum number of CPUs (2-32) (CONFIG_NR_CPUS) [32] (should be enough :-)
  CONFIG_CISS_MONITOR_THREAD=y
  CONFIG_IP_VS=N (virtual stuff not really needed for now)
  Inside CONFIG_SK98LIN=M (Marvell Yukon Chipset / SysKonnect SK-98xx Support)
  9 Y'es to all card options
  Inside CONFIG_NET_RADIO=y [Wireless LAN (non-hamradio)]
  CONFIG_TMD_HERMES=n (support incomplete and buggy)
  CONFIG_HW_RANDOM=m
  CONFIG_AGP_ATI=y (ATI IGP chipset support)
  CONFIG_DRM_GAMMA=m (3dlabs GMX 2000)
  CONFIG_FB_ATY_GENERIC_LCD=y (Mach64 generic LCD monitor support)
  Inside ALi5455 audio support (CONFIG_SOUND_ALI5455=M)
  4 Y'es to all options
  AD1980 front/back switch plugin (CONFIG_SOUND_AD1980)=M
  Wolfson Touchscreen/BMON plugin (CONFIG_SOUND_WM97XX)=M
  Kernel messages buffer length shift (0 = default) (CONFIG_LOG_BUF_SHIFT) [0] 
  Inside Cryptographic API (CONFIG_CRYPTO)
  CAST5 (CAST-128) cipher algorithm (CONFIG_CRYPTO_CAST5)=M
  Hotplug firmware loading support (EXPERIMENTAL) (CONFIG_FW_LOADER)=M
- fails build:
  crc32.c:91: warning: static declaration for `fn_calc_memory_chunk_crc32' follows non-static
  airo.c:207: redefinition of `PDE'
  /usr/src/redhat/BUILD/kernel-2.4.22/linux-2.4.22/include/linux/proc_fs.h:213: `PDE' previously defined here
  make[3]: *** [airo.o] Error 1
* Wed Sep 10 2003 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.4.22-6.ll
- disabled CONFIG_ATM_HE=m, there is still an unresolved symbol, should
  not have an impact on existing users as it is new on 2.4.22
- added usb-uhci patch from http://www.bewan.com/bewan/drivers/bapst-0.6.1.tar.gz,
  prevents a freeze when loading the driver, the usb-ohci has already ben
  incorporated into 2.4.22
* Sat Sep  6 2003 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.4.22-5.ll
- more work adding RedHat patches...
- added CONFIG_SCSI_NEWISP=m, feral qlogic isp patch (patch2401, patch2410)
- added CONFIG_ECC=, ECC memory support (patch5050)
- looked again at CONFIG_TC35815, seems to be there in 2.4.22 but it is
  a mips only option (?)
- a new diff of config files yields:
  Missing in new config and set in old config:
  CONFIG_CPU_FREQ=y, CONFIG_X86_POWERNOW_K6=m, CONFIG_X86_SPEEDSTEP=m:
    handled by the ACPI subsystem
  CONFIG_HIGHPTE=y: vm changes, ignored
  CONFIG_TUX=m: we don't need tux
  CONFIG_IP_ROUTE_LARGE_TABLES=y: is not a patch, so ignored
  CONFIG_TC35815=m: apparently in 2.4.22, only for mips
  CONFIG_NETCONSOLE=m: network console dump
  CONFIG_KALLSYMS=y: load all symbols for debugging
  Added:
  CONFIG_EDD=m (linux-2.4.20-edd[-allocate].patch): added (patch661, patch662)
* Wed Sep  5 2003 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.4.22-4.ll
- diff'ed i686 config file for redhat 2.4.20-20.x and 2.4.22-3.ll.acpi, this should
  make the Planet CCRMA kernel to be closer to RedHat's, here's a summary of the
  differences and changes made:
  -CONFIG_X86_L1_CACHE_SHIFT=7
  +CONFIG_X86_L1_CACHE_SHIFT=5
    seems to be set automatically...
  Added: 
  CONFIG_BLK_STATS=y, CONFIG_IP_NF_MATCH_AH_ESP=m, CONFIG_APM_CPU_IDLE=y, 
  CONFIG_IP_NF_NAT_LOCAL=y, CONFIG_IP_NF_TARGET_ULOG=m, CONFIG_ATM_BR2684_IPFILTER=y, 
  CONFIG_DEV_APPLETALK=y, CONFIG_NET_DIVERT=y, CONFIG_PDC202XX_FORCE=y, 
  CONFIG_AIC79XX_CMDS_PER_DEVICE=253, CONFIG_FEALNX=m, CONFIG_SK98LIN=m, 
  CONFIG_PPPOE=m, CONFIG_IPHASE5526=m, CONFIG_ATI_XX20=m, CONFIG_IPMI_HANDLER=m,
  CONFIG_W83877F_WDT=m, CONFIG_AMD_PM768=m, CONFIG_JFS_FS=m, CONFIG_FB_VGA16=m,
  CONFIG_USB_SERIAL_KEYSPAN_USA19W=y, CONFIG_USB_SERIAL_KEYSPAN_USA49W=y,
  CONFIG_USB_BRLVGER=m, CONFIG_BLUEZ_SCO=m, CONFIG_BLUEZ_USB_ZERO_PACKET=y,
  CONFIG_BLUEZ_HCIUART_H4=y, CONFIG_BLUEZ_HCIDTL1=m, CONFIG_CRYPTO (enable all),
  CONFIG_QFMT_V2=y, CONFIG_BEFS_FS=m
  Kept (new options):
  CONFIG_BLK_DEV_SC1200=y, CONFIG_SYNCLINKMP=m, CONFIG_I2C_I810=m, 
  CONFIG_DRM_SIS=m, CONFIG_NTFS_FS=m, CONFIG_NFSD_TCP=y, CONFIG_FB_MATROX_PROC=m,
  CONFIG_USB_EMI26=m, CONFIG_USB_DC2XX=m
- added patch to fix sk98lin build (unresolved symbol)
- no tux patches so no tux (kernel http server)
- added old wvlan driver (patch5030, CONFIG_PCMCIA_WVLAN=m)
- added old orinoco driver (patch 1450, CONFIG_PCMCIA_HERMES_OLD=m)
- added gericom improvements for laptops (patch2420, CONFIG_BATTERY_GERICOM=m)
- did not add CONFIG_VIDEO_IGNORE_BAD_MODE, only needed for BOOT kernel
- did not add CONFIG_FB_ATY_CT_VAIO_LCD
  (in linux-2.4.20-selected-ac-bits)
- did not add CONFIG_SOUND_AUDIGY (we use alsa after all)
- delete CONFIG_USB_SERIAL_KEYSPAN_USA19=y, add CONFIG_USB_SERIAL_KEYSPAN_USA19W=y
  (fixes mistake made earlier...)
- tried snapshot of afs client (patch 5250, CONFIG_AFS_FS=m), does not build
- did not add CONFIG_HIGHPTE, depends on big vm patch
- did not add CONFIG_EDD=m, BIOS Enhanced Disk Drive Services
- did not add CONFIG_SCSI_NEWISP=m, feral qlogic isp patch (added 9/6/03)
- did not add CONFIG_TC35815 (in linux-2.4.17-selected-ac-bits)
- did not add CONFIG_NETCONSOLE=m, network dump console
- did not add CONFIG_KALLSYMS=y
- did not add CONFIG_ECC=, ECC memory support (added 9/6/03)
- added patches for CONFIG_CRYPTO=m and CONFIG_CRYPTO_BROADCOM=m
- added iSCSI driver (patch5120)
- added Dell's megarac (patch5010)
- added qla2x00 driver (patch5210)
- and finally, drop the "acpi" suffix for the kernel release as the ACPI patch is
  now part of the stable kernel
* Thu Sep  1 2003 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.4.22-3.ll.acpi
- added nfs patches, needed for 2.4.22 (otherwise I get nfs timeouts and 
  sometimes system locks when using nfs2 over udp - nfs3 seems to be better
  without the patches but still gets timeouts)
* Thu Aug 28 2003 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.4.22-2.ll.acpi
- diffed spec file with latest redhat, 2.4.20-20.9, updated some changes
  in the build procedure and file lists, should make this kernel more
  like redhat's.
* Mon Aug 25 2003 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.4.22-1.ll.acpi
- updated to 2.4.22 final!
- we don't need the acpi patch for 2.4.22 final
* Fri Aug 22 2003 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.4.21-4.ll.acpi
- trying latest acpi patch for 2.4.22-rc2
* Sat Aug  9 2003 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.4.21-3.ll.acpi
- trying 2.4.22-rc2
- latest (0730) acpi patch does not build cleanly, try 0714 instead
* Tue Aug  9 2003 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.4.21-3.ll.acpi
- trying 2.4.22-rc1
- memory stick patch no longer needed
* Tue Aug  9 2003 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.4.21-2.ll.acpi
- remove pcmcia directory and links so that pcmcia startup script works, 
  this is done only on redhat 9 through nptlarchs 
- add lm_sensors patch
* Fri Jun 13 2003 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.4.21-1.ll.acpi
- updated to 2.4.21!
* Tue Jun  3 2003 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.4.20-12.ll.acpi
- updated to 2.4.20-rc7
* Thu May 30 2003 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.4.20-11.ll.acpi
- updated to 2.4.20-rc6
- updated to acpi-20030523-2.4.21-rc3 patch
- reenabled ide-akpm.patch (newer patch from website)
* Wed May 29 2003 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.4.20-10.ll.acpi
- updated to 2.4.20-rc5
- VIA8237 fix from Alan Cox
* Tue May 28 2003 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.4.20-9.ll.acpi
- updated to 2.4.20-rc4
- ide-akpm.patch.txt, requested by digitalsin at earthlink.net, does not build
* Sat May 23 2003 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.4.20-8.ll.acpi
- updated to 2.4.20-rc3
- tweak low latency patch to patch cleanly
- added kernel-version-arch provides
* Wed May 14 2003 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.4.20-7.ll.acpi
- added kernel-arch provides
- turned off terminate build on unpackaged docs or files
- get rid of old kernel-up and kernel-source-headers package
* Tue May 13 2003 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.4.20-6.ll.acpi
- updated to 2.4.20-rc2
- added redhat 9 drm 4.3 patch, tweaked drm low latency patch to patch
- added provides of newer version of drm
- updated to acpi of 20030512 for 2.4.21-rc2
- deleted CONFIG_IPHASE5526 from configuration, still has unresolved symbols
- tried adding cipe/bcm driver from redhat 9, failed with compilation error
* Tue May  6 2003 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.4.20-5.ll.acpi
- updated to 2.4.21-rc1
- updated rtc patch
- updated to acpi of 20030424
* Sat Mar 29 2003 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.4.20-4.ll.acpi
- provide full kernel version in separate virtual package so that apt
  can select proper kernel dependency for alsa kernel modules install
* Thu Mar 27 2003 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.4.20-4.ll.acpi
- update to 2.4.21-pre6
- update to acpi-20030321-2.4.21-pre5
- ptrace hole now fixed in pre6
- fixed documentation file list
* Mon Mar 24 2003 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.4.20-3.ll.acpi
- change makedependall to only avoid building debug and bigmem dependencies
- no longer generate custom kernel-up package (added a define)
- updated documentation package file list
* Thu Mar 20 2003 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.4.20-3.ll.acpi
- fixed ptrace hole patch and rtc patch to patch cleanly
* Wed Mar 19 2003 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.4.20-2.3.ll.acpi
- added alsa rtc patch, does not patch cleanly
* Tue Mar 19 2003 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.4.20-2.3.ll.acpi
- added Alan Cox's ptrace hole patch (erased um chunk)
  does not patch cleanly...
* Fri Feb 28 2003 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.4.20-2.1.ll.acpi
- updated to 2.4.21-pre5
- redid 003_rl2_021215_ck.2.4.20-pre5.patch so it patches cleanly
- updated to acpi-20030228-2.4.21-pre4.diff.gz
- added ieee1394 patch from cvs, does not build, reverted it (20070)
- added 007_packet_030226_ck_2.4.20.patch.bz2, does not patch cleanly
- added small patch to build normal iee1394 (20071, found on lkml)
- sbp2 patch no longer needed
* Sun Feb  2 2003 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.4.20-1.12.ll.acpi
- delete calls to set_cpus_allowed from 2.4.21-pre4, they break smp
  build
- updated to latest acpi patch (20030125-2.4.21-pre3)
* Sat Feb  1 2003 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.4.20-1.11.ll.acpi
- update to 2.4.21-pre4
- scx200 ide driver still does not compile, disabled
- sbp2 compile errors, enable patch from ac1
- ipmi driver compile errors, disabled
- undefined reference to set_cpus_allowed in apm (smp)
- try pre4-ac1, too many changes to the scheduler, lowlat and preempt fail
  to patch successfully
* Mon Jan 20 2003 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.4.20-1.10.ll.acpi
- added xfs patch. ha, does not patch cleanly (part of Kolivas's patches)
* Mon Jan 20 2003 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.4.20-1.9.ll.acpi
- go back to 1.6.ll.acpi (plain 2.4.20)
- add ext3 scheduling storm patch, fixes hangs with jack using SCHED_FIFO
* Wed Jan 15 2003 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.4.20-1.8.ll.acpi
- updated to 2.4.21-pre3, disabled SCx200 driver, has compile errors
* Thu Jan  2 2003 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.4.20-1.7.ll.acpi
- added 2.4.21-pre2, tweaked low-latency and preempt patches for 2.4.21-pre2
- added small patch to make drivers/ieee1394/sbp2.c compile
- argh, as usual, unresolved symbols:
  erased the modules to be able to test... still hanging
* Tue Dec 31 2002 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.4.20-1.6.ll.acpi
- the O(1) scheduler seems to not work very well for interactive processes
  during a big compile process (jerky mouse motion etc).
- apply ll, preempt, remove ll/pe/o(1), aavm and desktop tuning from Koliva's 
  set, apply the rest, remove the bnep patch that is needed by o(1).
* Mon Dec 30 2002 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.4.20-1.5.ll.acpi
- added latest ext3 patches for 2.4.20 (it seems that the deadlocks are due
  to ext3)
* Fri Dec 27 2002 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.4.20-1.4.ll.acpi
- downloaded latest Con Koliva's patches
- HZ is now configurable at kernel configuration time (set to 1000)
* Fri Dec 13 2002 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.4.20-1.3.ll.acpi
- test again Con Koliva's patches, do not include xfs or supermount
* Thu Dec 12 2002 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.4.20-1.2.ll.acpi
- downloaded real lowlat for 2.4.20 from Andrew Morton's site, new acpi from
  20021205. 
  alsa_pcm: xrun of at least 138.280 msecs
  alsa_pcm: xrun of at least 1098.954 msecs
  alsa_pcm: xrun of at least 348.778 msecs
  alsa_pcm: xrun of at least 507.613 msecs
  alsa_pcm: xrun of at least 840.302 msecs
  alsa_pcm: xrun of at least 2.382 msecs
  alsa_pcm: xrun of at least 454.772 msecs
  alsa_pcm: xrun of at least 465.636 msecs
  alsa_pcm: xrun of at least 7.860 msecs
  alsa_pcm: xrun of at least 1.516 msecs
  alsa_pcm: xrun of at least 6.008 msecs
  alsa_pcm: xrun of at least 175.399 msecs
  alsa_pcm: xrun of at least 253.294 msecs
  alsa_pcm: xrun of at least 27.081 msecs
* Tue Dec 10 2002 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.4.20-1.1.ll.acpi
- tried Con Koliva's patches for low latency
* Fri Dec  6 2002 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.4.20-1.ll.acpi
- updated to 2.4.20, acpi-20021126-2.4.20-rc3, preempt-kernel-rml-2.4.20-rc3-1
- disabled compilation of the SysKonnect SK-98xx gigabit ethernet driver, it
  has an unresolved symbol problem
- change HZ to 1000
* Sat Nov 11 2002 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.4.19-3.1.ll.acpi
- updated to 2.4.20-rc2
- added makedependall switch to minimize the make depends and speed up compile
- change HZ to 500
* Tue Aug 20 2002 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.4.19-3.ll.acpi
- updated to 2.4.19, 2.4.20-rc1, acpi for 2.4.20-pre11, low latency for 2.4.20-rc1,
  preempt. Copied configuration from the 2.4.19-2.ll kernel.
- patches installed:
    capabilities patch
    usb memory stick patch
    acpi-20021024-2.4.20-pre11
    preempt-kernel-rml-2.4.20-pre10-1
    2.4.20-rc1-low-latency.patch
--> complete hang when using jackd+freqtweak
- patches installed (erased preemptible kernel patch):
    capabilities patch
    usb memory stick patch
    acpi-20021024-2.4.20-pre11
    2.4.20-rc1-low-latency.patch
--> complete hang when using jackd+freqtweak
- test:
    capabilities patch
    usb memory stick patch
    acpi-20021002-2.4.20-pre8
    preempt-kernel-rml-2.4.20-pre10-1
    2.4.20-rc1-low-latency.patch
  
* Sat Jul 24 2002 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.4.18-12.1.ll.acpi
- added drm low latency patch
- added read only ntfs support
* Wed Jul 24 2002 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.4.18-12.ll.acpi
- need acpi for laptops, go back to plain 2.4.18, patch with acpi patches, 
  tweak an old low latency patch to work

* Wed Jul 24 2002 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.4.18-12.ll
- update to 2.4.19-rc3, added the option of compiling acpi into the kernel
  got an "unofficial patch" for rc3 from:
  http://codecs.home.sapo.pt/acpi/
  list thread: http://sourceforge.net/mailarchive/message.php?msg_id=1864175

* Thu Jul 18 2002 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.4.18-11.ll
- update to 2.4.19-rc2, 2.4.19-pre10-low-latency, preempt-kernel-rml-2.4.19-rc2-1, 
  linux-cap_setpcap

* Wed Jul  3 2002 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu>
- build with kgcc under redhat 7.2 (regular gcc under 7.3) - but with 
  compat-egcs-6.2-1.1.2.16 the kernel does not build, so go back to gcc
  and cross fingers. 

* Tue Jul  2 2002 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.4.18-10.ll
- update to 2.4.19-rc1, 2.4.19-pre10-low-latency, preempt-kernel-rml-2.4.19-pre9-1, 
  linux-cap_setpcap

* Sat Jun  1 2002 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.4.18-9.ll
- added package kernel-up, meant to eliminate problems with apt for rpm when
  dealing with "kernel" as a package name _and_ virtual package name, it is 
  a duplicate of the base kernel package. 

* Fri May 17 2002 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.4.18-8.ll
- back to 2.4.19-pre8, hacked low latency for pre7 to patch under pre8, drm
  low latency patch from Jussi Laako, preemptible kernel patch (no statistics).

* Fri May 17 2002 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.4.18-7.ll
- only preemptible kernel patch with break locks and stats (turns out it is worse
  in terms of latency that the lowlat patch)

* Fri May 17 2002 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.4.18-6.ll
- updated to 2.4.19-pre8, hacked low latency for pre7 to patch under pre8,
  added preemptible kernel patch, added statistcs for preemptible kernel patch

* Sat May 11 2002 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.4.18-4.ll
- add drm latency fixes from Jussi Laako (jussi.laako@kolumbus.fi)
  see http://www.pp.song.fi/~visitor/linux/, fixes dri latency hits

* Sat Apr 19 2002 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu>
- excluded the pcilynx support from the ieee1934 system
- added sysctl control of the low latency patch
- added conditionals for /lib/kernel/
- undefined ibcs
- disabled CONFIG_W83877F_WDT watchdog timer (error on i586-smp)
- disable bcm rpm requirement

* Fri Apr 18 2002 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu>
- changed name of src link to "linux"
- added capabilities patch
- added source-headers package creation
- added vmlinuz linking for smp install
- allow building uniprocessor i586

* Fri Apr 12 2002 Stephen C. Tweedie <sct@redhat.com>
- Add patch for misc fixes to block device buffer handling.

* Tue Apr 11 2002 Arjan van de Ven <arjanv@redhat.com>
- documented spec a bit more
- added suspend/resume fix from 2.4.9-31 to avoid regression
- added watcom usb ID's

* Tue Apr 09 2002 Pete Zaitcev <zaitcev@redhat.com>
- Sanitizing moremounts. Arjan fixed 62740 there by concatenation of patches.

* Tue Apr 09 2002 Arjan van de Ven <arjanv@redhat.com>
- final serverworks/acard/promise IDE bits

* Mon Apr 08 2002 Arjan van de Ven <arjanv@redhat.com>
- sort "hpt366 doesn't boot" issues
- add promise IDE patch from upstream to fix hang

* Fri Apr 05 2002 Arjan van de Ven <arjanv@redhat.com>
- put fstat patch back in
- fix kksymoops

* Mon Apr 01 2002 Pete Zaitcev <zaitcev@redhat.com>
- ide-tape: un-regress 36628, fix 62267.
- Tentatively added USB serial fix 61820.

* Wed Mar 27 2002 Stephen C. Tweedie <sct@redhat.com>
- Add LVM atomic filesystem snapshots patch

* Wed Mar 27 2002 Arjan van de Ven <arjanv@redhat.com>
- some IDE updates from Andre Hedrick
- eepro100 PCI ID's
- updated module-info (harald)
- bugfixes from 2.4.18-pre4-ac2

* Tue Mar 26 2002 Benjamin LaHaise <bcrl@redhat.com>
- add aio 20020326
- correct aio library install path

* Tue Mar 26 2002 Arjan van de Ven <arjanv@redhat.com>
- update megaraid to 1.18a

* Mon Mar 25 2002 Benjamin LaHaise <bcrl@redhat.com>
- fix mmap for odd drivers / vsyscalls

* Mon Mar 25 2002 Arjan van de Ven <arjanv@redhat.com>
- update e100/e1000
- update tg3 driver
- new logo graphics
- update qla2200 driver
- added megarac driver (still needs a lot of work)
- update iscsi

* Fri Mar 22 2002 Arjan van de Ven <arjanv@redhat.com>
- update to have the fixes from 2.4.19-pre3-ac5

* Tue Mar 19 2002 Pete  Zaitcev <zaitcev@redhat.com>
- restored the "moreunnamed" patch, which conflicted with Al's cleanups.

* Tue Mar 19 2002 Arjan van de Ven <arjanv@redhat.com>
- add more accurate process accounting from later -ac

* Thu Mar 14 2002 Benjamin LaHaise <bcrl@redhat.com>
- make sym53c8xx_2 actually called sym53c8xx_2.o

* Fri Mar 08 2002 Benjamin LaHaise <bcrl@redhat.com>
- add fix for inode sync problem (linux-2.4.18-sync_one.patch)

* Mon Mar 04 2002 Arjan van de Ven <arjanv@redhat.com>
- 2.4.18-ac3
- removed some stale patches
- added compaq driver update
- added tigon3 driver

* Fri Mar  1 2002 Stephen C. Tweedie <sct@redhat.com>
- Add akpm's get_request fairness patch from 2.4.19-pre1

* Thu Feb 28 2002 Stephen C. Tweedie <sct@redhat.com>
- Add linux-2.4.17-lvm-fixes.patch for miscellaneous local LVM fixes and
  tweaks.

* Wed Feb 27 2002 Stephen C. Tweedie <sct@redhat.com>
- Add bugfixes from LVM-1.0.3

* Mon Feb 25 2002 Arjan van de Ven <arjanv@redhat.com>
- updated e1000 driver to the GPL compatible version

* Fri Feb 22 2002 Pete Zaitcev <zaitcev@redhat.com>
- Bug 35215 patch #1261

* Fri Feb 22 2002 Doug Ledford <dledford@redhat.com>
- Forward port the iorl changes that were made for the 2.4.9 kernel
- Added the changes for the aic7xxx_old driver related to the iorl work

* Thu Feb 21 2002 Stephen C. Tweedie <sct@redhat.com>
- Merge in mempool from 2.5 for LVM's use.

* Wed Feb 20 2002 Pete Zaitcev <zaitcev@redhat.com>
- s390x in ExclusiveArch

* Wed Feb 20 2002 Arjan van de Ven <arjanv@redhat.com>
- 2.4.18rc2

* Fri Feb 19 2002 David Woodhouse <dwmw2@redhat.com>
- update ARM patch
- ARM rmap

* Fri Feb 15 2002 Arjan van de Ven <arjanv@redhat.com>
- update to 2.4.18rc1
- update O(1) scheduler
- update rmap

* Thu Feb 14 2002 Stephen C. Tweedie <sct@redhat.com>
- Add LVM atomic move patch

* Sun Feb 10 2002 Arjan van de Ven <arjanv@redhat.com>
- 2.4.18pre9

* Fri Feb 08 2002 Pete Zaitcev <zaitcev@redhat.com>
- Workaround for broken hardware for #55878.

* Mon Feb 04 2002 Arjan van de Ven <arjanv@redhat.com>
- updated linux-abi patch
- made the bootup printk's less noisy by default
- merged 2.4.18pre8

* Sat Jan 26 2002 Arjan van de Ven <arjanv@redhat.com>
- update to 2.4.18pre7 and rmap12a

* Sun Jan 14 2002 Arjan van de Ven <arjanv@redhat.com>
- added DRM for XFree86 4.2.0
- made a "pinned list" for the rmap VM as to keep mlock()ed pages
  out of the way of the VM.

* Fri Jan 12 2002 Arjan van de Ven <arjanv@redhat.com>
- O(1) scheduler
- JFS 1.0.12 for evaluation

* Tue Dec 18 2001 Michael K. Johnson <johnsonm@redhat.com>
- Added watchdog patch

* Wed Dec 12 2001 Pete Zaitcev <zaitcev@redhat.com>
- Keep fix for #55420, while postponed by Marcelo.

* Wed Dec 12 2001 Arjan van de Ven <arjanv@redhat.com>
- updated qla2200/2300 driver

* Tue Dec 11 2001 Arjan van de Ven <arjanv@redhat.com>
- update to 2.4.17-pre8

* Fri Dec 07 2001 Arjan van de Ven <arjanv@redhat.com>
- update to 2.4.17-pre5
- add 32 bit quota back
- add netfilter bridging patches

* Wed Dec 05 2001 Arjan van de Ven <arjanv@redhat.com>
- update to 2.4.17-pre3
- aacraid update

* Fri Nov 30 2001 Pete Zaitcev <zaitcev@redhat.com>
- Fix kfree of static in sd.c:sd_init()

* Fri Nov 30 2001 David Woodhouse <dwmw2@redhat.com>
- update ARM kernel patch to 2.4.16-rmk1

* Thu Nov 29 2001 Philip Copeland <bryce@redhat.com>
- retired the previous ipvs patchs (5800,5810,5820)
  new single ipvs patch

* Thu Nov 29 2001 Arjan van de Ven <arjanv@redhat.com>
- disable ipvs
- add qla2200 driver

* Tue Nov 27 2001 Arjan van de Ven <arjanv@redhat.com>
- update to 2.4.16
- tux update

* Fri Nov 23 2001 Arjan van de Ven <arjanv@redhat.com>
- update to 2.4.15

* Fri Nov 16 2001 David Woodhouse <dwmw2@cambridge.redhat.com>
- Merge MIPS kernel support

* Thu Nov 15 2001 David Woodhouse <dwmw2@cambridge.redhat.com>
- Merge SH kernel support

* Wed Nov 14 2001 Pete Zaitcev <zaitcev@redhat.com>
- Fix for #36059 (ymfpci). This bug is pushed to Linus, but I wish
  this to be in our tree all the same, for the sake of erratas.

* Mon Nov 12 2001 David Woodhouse <dwmw2@cambridge.redhat.com>
- Merge ARM kernel support

* Sat Nov 03 2001 Arjan van de Ven <arjanv@redhat.com>
- update to 2.4.13-ac7

* Sun Oct 28 2001 Pete Zaitcev <zaitcev@redhat.com>
- Added workaround for #54390, reads from dasd return trailing garbage.
- Not applying s390 specific ac14 parts anymore: all there already.

* Sun Oct 28 2001 Arjan van de Ven <arjanv@redhat.com>
- update to 2.4.13-ac4

* Tue Oct 16 2001 Pete Zaitcev <zaitcev@redhat.com>
- Killed port-specific __cpu_raise_softirq on s390 and s390x (warning flood)
- Removed loopfix part from linux-2.4.9-s390-ac11.patch, now generic.

* Sat Oct 13 2001 Pete Zaitcev <zaitcev@redhat.com>
- usb-uhci bugfix from mainstream, until it reaches us down the line

* Wed Oct 10 2001 Pete Zaitcev <zaitcev@redhat.com>
- ide-tape fix for HP Colorado, #36628

* Mon Oct 8 2001 Arjan van de Ven <arjanv@redhat.com>
- New Broadcom 5700/5701 driver version
- ptrace patches

* Mon Oct 8 2001 Stephen Tweedie <sct@redhat.com>
- Fix ext3 directory readahead bug on empty (deleted) directories

* Sun Oct 7 2001 Arjan van de Ven <arjanv@redhat.com>
- merge 2.4.10-ac7 bugfixes
- make alpha compile again

* Fri Oct 5 2001 Stephen Tweedie <sct@redhat.com>
- Bring ext3 up to version 0.9.11

* Fri Oct 5 2001 Arjan van de Ven <arjanv@redhat.com>
- went back to old emu10k driver; the new one has too many problems
- added PPP over ATM patch

* Thu Oct 4 2001 Arjan van de Ven <arjanv@redhat.com>
- merged a few 2.4.9-ac18 bugfixes

* Wed Oct 3 2001 Arjan van de Ven <arjanv@redhat.com>
- fixed hotplug driver to make system load not 1.00

* Mon Oct 1 2001 Arjan van de Ven <arjanv@redhat.com>
- update qla1280 driver

* Wed Sep 25 2001 Arjan van de Ven <arjanv@redhat.com>
- update Serverraid driver
- add quite a few MODULE_LICENSE() tags
- revert gendisk patch from -ac10
- add "tainted" patch from Keith Owens

* Mon Sep 23 2001 Arjan van de Ven <arjanv@redhat.com>
- updated ataraid to latest versions
- updated to block highmem patch version 15 
- updated hotplugpci patch

* Sun Sep 23 2001 Arjan van de Ven <arjanv@redhat.com>
- Add Rik van Riels VM tuning patch

* Sun Sep 23 2001 Florian La Roche <Florian.LaRoche@redhat.de>
- update s390 patches to 2.4.9ac14
- start s390x support
- add printk patch again

* Fri Sep 21 2001 Ingo Molnar <mingo@redhat.com>
- update TUX

* Fri Sep 21 2001 Arjan van de Ven <arjanv@redhat.com>
- added aic7xxx_old to the "highmem capable" devicelist

* Mon Sep 17 2001 Arjan van de Ven <arjanv@redhat.com>
- update Jens' block highmem patch
- add patch for 48bit IDE LBA 
- updated e100/e1000 drivers
- added sd maxsectors patch

* Sat Sep 15 2001 Florian La Roche <Florian.LaRoche@redhat.de>
- put all Red Hat specific s390 patches in one file

* Thu Sep 13 2001 Arjan van de Ven <arjanv@redhat.com>
- make freevxfs autoload

* Mon Sep 10 2001 Arjan van de Ven <arjanv@redhat.com>
- go to 2.4.9-ac10
- update linux-abi to upstream 2.4.9-0 version

* Thu Sep 06 2001 Arjan van de Ven <arjanv@redhat.com>
- fix oops in ia64 unwind (#52486)
- added /proc/unalignedinfo for ia64 (#42310) while
  disabling the evil printk's

* Wed Sep 05 2001 Arjan van de Ven <arjanv@redhat.com>
- go to 2.4.9-ac7

* Fri Aug 31 2001 Michael K. Johnson <johnsonm@redhat.com>
- make quota messages look saner
- pci hotplug modular

* Tue Aug 28 2001 Arjan van de Ven <arjanv@redhat.com>
- fixed oops on ieee1394 disconnect

* Mon Aug 27 2001 Arjan van de Ven <arjanv@redhat.com>
- add grubby to %post and %preun to automatically change grub.conf
- added patch to fix #50785 (cipe doesn't reload)
- minor updates from 2.4.9-ac1

* Mon Aug 27 2001 Stephen C. Tweedie <sct@redhat.com>
- Bring ext3 up to version 0.9.8: fixes an NFS oops, cleans up some
  printk log levels, updates error state on disk more rigorously and
  adds a "do_sync_supers" module parameter to allow the  sychronous
  superblock flush behaviour of ext3-0.9.6 to be restored on demand. 

* Sat Aug 25 2001 Ingo Molnar <mingo@redhat.com>
- fix the acenic driver bug that caused random kernel memory being
  sent out on the wire, on x86 systems with more than 4 GB RAM.

* Sat Aug 25 2001 Arjan van de Ven <arjanv@redhat.com>
- backout out the ewrk3 driver to the 2.4.2 version (#51961)
  as that one worked.
- disabled oom moderation
- added tulip_old driver (the 2.4.2/2.4.3 version) (#49966, #51622)
- added Doug's latest i810 driver (#49876)
- fixed USB device table (#51229)

* Fri Aug 24 2001 Benjamin LaHaise <bcrl@redhat.com>
- update ns83820 to v0.10

* Fri Aug 24 2001 Pete Zaitcev <zaitcev@redhat.com>
- Fix for 52229

* Fri Aug 23 2001 Arjan van de Ven <arjanv@redhat.com>
- updated e1000 driver (#52154)
- removed /sbin/installkernel from the kernel rpm (moved 
  to the initscripts rpm)
- created 'noathlon' DMI blacklist entry for MSI MS-6330 motherboards
- fixed tasklet bug reported by both Broadcom and Intel
- backout a segment reload optimisation, lkml has bad bugreports about it
- added aic7xxx config option patch (Doug)

* Fri Aug 23 2001 Stephen C. Tweedie <sct@redhat.com>
- added uptodate ext3 code from the ext3 abort-handle-branch
  to handle taking the filesystem offline/readonly on fatal error
  cleanly.

* Thu Aug 22 2001 Benjamin LaHaise <bcrl@redhat.com>
- added clear_page_tables lock patch

* Thu Aug 22 2001 Arjan van de Ven <arjanv@redhat.com>
- added periodic shrink of icache (#52374)
- merged trivial VM tuning patch from 2.4.8-ac9
- added more reservation bouncebuffers 
  for highmem performance (#52340)
- updated e100 driver to latest version

* Wed Aug 22 2001 Arjan van de Ven <arjanv@redhat.com>
- merged S390 patches from bero
- removed dmi chunk (#51458)
- merged bugfixes from 2.4.8-ac9 
- * posixthreads tid!=pid patch
- * scsi tape bugfixes

* Tue Aug 21 2001 Arjan van de Ven <arjanv@redhat.com>
- add scsi hang fix and USB net hang fix from 2.4.8-ac8

* Mon Aug 20 2001 Michael K. Johnson <johnsonm@redhat.com>
- modification to e1000 driver at Intel's request (#49571)

* Mon Aug 20 2001 Arjan van de Ven <arjanv@redhat.com>
- added PCI ID's for KT133A chipset to AGP/DRM
- added S390 tape patch (bero)
- add missing Fritz PCMCIA driver (#50999)
- removed CONFIG_BLK_DEV_OFFBOARD (#52073) as it was bogus
- merged several DRM fixes from 2.4.7-ac7

* Sat Aug 18 2001 Arjan van de Ven <arjanv@redhat.com>
- fix oops in NFS code
- merged "DRM scribbles memory" patch from SuSE

* Fri Aug 17 2001 Arjan van de Ven <arjanv@redhat.com>
- fix critical bugfixes from 2.4.8-ac6:
-  * cpu flags are unsigned long, not int (64 bit issue)

* Thu Aug 16 2001 Benjamin LaHaise <bcrl@redhat.com>
- added linux-2.4.9-vma_merge_full.patch vma merging patch that
  speeds up mozilla and gcc quite a bit

* Thu Aug 15 2001 Arjan van de Ven <arjanv@redhat.com>
- IKD included for the debug kernel
- add bcm5700 bugfixes (PCI access functions)
- upgraded wvlan_cs to not sleep with spinlocks helt (#51507)
- added "noathlon" bootflag (#50926)
- updated ia64 drm to upstream version, ifarch ia64 only

* Wed Aug 15 2001 Michael K. Johnson <johnsonm@redhat.com>
- clean up filelists a bit, add all_x86

* Wed Aug 15 2001 Arjan van de Ven <arjanv@redhat.com>
- fix "cardbus has IRQ 0 and crashes" bug (#51706)
- update i810 driver to fix oopses (Doug)
- add patch from 2.4.7-ac5 to fix a thinko in the VM

* Wed Aug 15 2001 Pete Zaitcev <zaitcev@redhat.com>
- Patch that allows to change USB printer probing order (#50218)

* Tue Aug 14 2001 Arjan van de Ven <arjanv@redhat.com>
- Made the USB keyboard patch not printk on every keypress
- added udelay(1) to the eepro100 driver
- merged bugfixes from 2.4.8-ac5
- added arch/ppc64 code, doesn't touch non-ppc

* Mon Aug 13 2001 Pete Zaitcev <zaitcev@redhat.com>
- Add fix for #51142 (Japanese USB keyboard).

* Mon Aug 13 2001 Stephen C. Tweedie <sct@redhat.com>
- Merge ext3-0.9.6

* Mon Aug 13 2001 Benjamin C.R. LaHaise <bcrl@redhat.com>
- updated linux-2.4.7-page_table_races.patch see bug #51652
- remove comments about set_page_dirty (it's actually okay)

* Mon Aug 13 2001 Michael K. Johnson <johnsonm@redhat.com>
- Minor specfile cleanups

* Mon Aug 13 2001 Arjan van de Ven <arjanv@redhat.com>
- critical bugfixes from 2.4.8-ac2
- more eepro100 PCI ID's (notting)
- more aacraid PCI ID's (adaptec)
- add patch to fix parport console pinning lp module (#51387)
- added LDT bugfix (from 2.4.8-ac2) needed for glibc

* Sun Aug 12 2001 Arjan van de Ven <arjanv@redhat.com>
- S/390 updates (Florian)

* Fri Aug 10 2001 Benjamin LaHaise <bcrl@redhat.com>
- update ns83820.c to v0.6

* Fri Aug 10 2001 Arjan van de Ven <arjanv@redhat.com>
- Added bigendian patch for ext3 (sct)
- fix resume on Dell Inspiron 8000 (#51407)
- fix oops in parport code (#51194)
- added bugfixes from 2.4.7-ac11, including fix for #49287
- Added MXT bugfix (IBM CRIT)
- removed fs/namei patch as it breaks too much

* Thu Aug 9 2001 Arjan van de Ven <arjanv@redhat.com>
- added patch from Broadcom to fix crash under high load (#51272, #51041) 
- merged bugfixes from 2.4.7-ac10; including switching to DRM4.1 from -ac10
- added Dell DMI entries for rebooting/suspend (#51269, #51202)
- added aacraid PCI ID's (#51246)
- synced S390 tree (bero)
- new iscsi drop from Cisco to comply with latest ietf standard

* Wed Aug 8 2001 Arjan van de Ven <arjanv@redhat.com>
- added ia64 TLB patch from Ben (#45204)
- added io elevator stall patch from Ben
- merge bugfixes from 2.4.7-ac9
- add IDE blacklist entries (#50775)

* Tue Aug 7 2001 Arjan van de Ven <arjanv@redhat.com>
- merged bugfixes from 2.4.7-ac8
- increased SCSI timeout (#50853)
- updated hotplug PCI patch (#50856)
- updated cpqfc driver (Compaq CRIT)
- added vfat-nfs patch (#50820, #50822, #45525, #37031)

* Mon Aug 6 2001 Arjan van de Ven <arjanv@redhat.com>
- merged bugfixes from 2.4.7-ac7
- updated bcm5820 driver
- updated linux-abi patch

* Fri Aug 3 2001 Arjan van de Ven <arjanv@redhat.com>
- Added DRI for XFree 4.1

* Thu Aug 2 2001 Arjan van de Ven <arjanv@redhat.com>
- fixed bug where inodes were cached WAAY too long (vm bug)
- Added ethtool support to several drivers (Dell)
- Updated bcm5820 driver

* Wed Aug 01 2001 Michael K. Johnson <johnsonm@redhat.com>
- ext3 no longer optional

* Wed Aug 1 2001 Arjan van de Ven <arjanv@redhat.com>
- updated to 2.4.7-ac3

* Tue Jul 31 2001 Arjan van de Ven <arjanv@redhat.com>
- Added DaveM's fix for the ethtool ioctl

* Wed Jul 25 2001 Guy Streeter <streeter@redhat.com>
- ppc build fixes
- mac and pSeries rpm and Makefile support

* Wed Jul 25 2001 Michael K. Johnson <johnsonm@redhat.com>
- update to cpqarray 2.4.5

* Tue Jul 24 2001 Michael K. Johnson <johnsonm@redhat.com>
- add spinlocks to cramfs decompression for SMP operation

* Tue Jul 24 2001 Ingo Molnar <mingo@redhat.com>
- fixed rare BUG in reclaim_page

* Mon Jul 23 2001 Michael K. Johnson <johnsonm@redhat.com>
- removed accidentally added and unneeded ia64 BOOT kernel

* Mon Jul 23 2001 Benjamin LaHaise <bcrl@redhat.com>
- update ns83820 driver to v0.5

* Mon Jul 23 2001 Arjan van de Ven <arjanv@redhat.com>
- Update MXT patch
- Updated GDTH driver
- Made EXT3 a module again
- Fixed module oops dumps
- Fiddled with VM some more
- Updated BCM5820 driver

* Sat Jul 21 2001 Arjan van de Ven <arjanv@redhat.com>
- made oom killer less trigger-happy

* Fri Jul 20 2001 Stephen C. Tweedie <sct@redhat.com>
- Fix slab-poison oops in ext3 checkpoint cleanup code

* Fri Jul 20 2001 Arjan van de Ven <arjanv@redhat.com>
- made EXT3 nonmodular to allow for better debugging/oopstracing
- updated e1000 driver to new version from Intel

* Thu Jul 19 2001 Stephen C. Tweedie <sct@redhat.com>
- Merge in ext3-0.9.3

* Thu Jul 19 2001 Arjan van de Ven <arjanv@redhat.com>
- updated to 2.4.6-ac5
- updated cciss driver
- renabled tux
- added Florian's s390 patch

* Mon Jul 16 2001 Stephen C. Tweedie <sct@redhat.com>
- Added ext3 fix for block allocation race

* Fri Jul 13 2001 Philip Copeland <bryce@redhat.com>
- Removed extra show_stack() function on the end of the tux2 patch
  arch/alpha/kernel/traps.c +103 and +129

* Fri Jul 13 2001 Michael K. Johnson <johnsonm@redhat.com>
- Added raid1 wait_event patch

* Thu Jul 12 2001 Arjan van de Ven <arjanv@redhat.com>
- added updated cpqfc driver

* Tue Jul 10 2001 Ingo Molnar <mingo@redhat.com>
- merge multipath patch

* Mon Jul 09 2001 Michael K. Johnson <johnsonm@redhat.com>
- change from 8 to 32 available swap areas (~1k memory cost)

* Sun Jul 08 2001 Arjan van de Ven <arjanv@redhat.com>
- Added Pete's patch to fix the IDE tape

* Sat Jul 07 2001 Arjan van de Ven <arjanv@redhat.com>
- Added patch to not allocate highmem bouncepages on non-highmem machines
- fixed ia64 boot

* Fri Jul 06 2001 Arjan van de Ven <arjanv@redhat.com>
- Updated Broadcom bcm5700 driver

* Thu Jul 05 2001 Arjan van de Ven <arjanv@redhat.com>
- updated airo_cs driver

* Thu Jul 05 2001 Michael K. Johnson <johnsonm@redhat.com>
- initrd_dir because ia64 uses /boot/efi

* Mon Jul 03 2001 Arjan van de Ven <arjanv@redhat.com>
- Update hpt/pdcraid support
- updated to 2.4.5-ac23

* Mon Jul 02 2001 Michael K. Johnson <johnsonm@redhat.com>
- Removed nested ifarch's from %build/%files by adding arch exclusions

* Thu Jun 28 2001 Arjan van de Ven <arjanv@redhat.com>
- Add prefetch() support to ia64

* Wed Jun 27 2001 Arjan van de Ven <arjanv@redhat.com>
- 2.4.5-ac19
- fixed O(N^2) algorithm in buffercache sync code

* Tue Jun 26 2001 Philip Copeland <bryce@redhat.com>
- updated IPVS

* Tue Jun 26 2001 Arjan van de Ven <arjanv@redhat.com>
- Added patch fom Jakub to fix sections

* Mon Jun 25 2001 Arjan van de Ven <arjanv@redhat.com>
- Added patch from marcelo@conectiva.com.br to show better swapinfo

* Sun Jun 24 2001 Arjan van de Ven <arjanv@redhat.com>
- Updated HPT370 driver

* Fri Jun 22 2001 Arjan van de Ven <arjanv@redhat.com>
- added HPT370 driver
- reverted xircom_cb to older version

* Fri Jun 22 2001 Michael K. Johnson <johnsonm@redhat.com>
- a bit more RPM flexibility with more existence macros
- conditionalize tape and BOOTtape kernels

* Thu Jun 21 2001 Arjan van de Ven <arjanv@redhat.com>
- reverted borken ext3 bit
- 2.4.5-ac17
- added /proc/sys/kernel/cad_pid patch

* Wed Jun 20 2001 Arjan van de Ven <arjanv@redhat.com>
- renumbered all the patches for future expansion / better separation
- new hotplug patch
- MXT patch

* Wed Jun 20 2001 Michael K. Johnson <johnsonm@redhat.com>
- speed things up a bit more for test builds:
  o buildup define for choosing whether to build the uniprocessor kernel
  o builddevfsd define ditto for devfsd (devfs itself still off)

* Tue Jun 19 2001 Arjan van de Ven <arjanv@redhat.com>
- updated to 2.4.5-ac16

* Mon Jun 18 2001 Arjan van de Ven <arjanv@redhat.com>
- added updated pdcraid driver

* Sun Jun 17 2001 Arjan van de Ven <arjanv@redhat.com>
- added CONFIG_SMALL, will need more tweaks for the BOOT kernel still

* Sat Jun 16 2001 Arjan van de Ven <arjanv@redhat.com>
- 2.4.5-ac15

* Fri Jun 15 2001 Arjan van de Ven <arjanv@redhat.com>
- moved to 2.4.5-ac14
- made i386 optimize for cpu=586
- disabled TUX for VM testing
- updated ext3


* Mon Jun 11 2001 Michael K. Johnson <johnsonm@redhat.com>
- killed some spec file cruft, made the spec file easier to maintain

* Sat Jun 09 2001 Arjan van de Ven <arjanv@redhat.com>
- 2.4.5-ac12
- New aacraid driver

* Sat Jun 09 2001 Michael K. Johnson <johnsonm@redhat.com>
- ieee1394 update

* Fri Jun  8 2001 Bill Nottingham <notting@redhat.com>
- add 0530 ia64 patch, make it apply, etc.

* Thu Jun 07 2001 Arjan van de Ven <arjanv@redhat.com>
- Added Marcelo's swap patch
- added but disabled new DRM code

* Mon Jun  4 2001 Bill Nottingham <notting@redhat.com>
- add locking fix for usb-uhci from Pete Zaitcev to linux-2.4.3-usb.patch

* Tue May 29 2001 Pete Zaitcev <zaitcev@redhat.com>
- re-enable usb patches 263, 271. The latter is on its way out but
  we need it still.

* Tue May 29 2001 Bill Nottingham <notting@redhat.com>
- regen ia64 patch

* Tue May 29 2001 Arjan van de Ven <arjanv@redhat.com>
- 2.4.5-ac3
- updated EXT3
- Added hotplug pci for test
- Added VM patch by Andrea

* Mon May 28 2001 Arjan van de Ven <arjanv@redhat.com>
- go to 2.4.5-ac2

* Sat May 26 2001 Arjan van de Ven <arjanv@redhat.com>
- merge base to 2.4.5-ac1

* Fri May 25 2001 Arjan van de Ven <arjanv@redhat.com>
- 2.4.4-ac17 (mostly null pointer fixes)
- New version of 3ware driver
- New version of symbios driver
- New version of FreeVxFS 
- Added ECC module
- merge base to 2.4.4-ac17

* Thu May 24 2001 Arjan van de Ven <arjanv@redhat.com>
- Added rawio fix from Shinya Narahara
- New version of EXT3

* Thu May 24 2001 Michael K. Johnson <johnsonm@redhat.com>
- modprobe loop on preun as well

* Wed May 23 2001 Arjan van de Ven <arjanv@redhat.com>
- 2.4.4-ac14

* Tue May 22 2001 Arjan van de Ven <arjanv@redhat.com>
- Added fixes from 2.4.4-ac12 and ac13

* Mon May 21 2001 Arjan van de Ven <arjanv@redhat.com>
- Added Jakub's ELF loader patch
- Added i82365 patch
- Updated TUX2 patch to 2.4.4 E4 level

*  Fri May 18 2001 Philip Copeland <bryce@redhat.com>
- added ext3 support for 2.4 (EXPERIMENTAL AND **NOT** FOR PRODUCTION)

*  Fri May 18 2001 Philip Copeland <bryce@redhat.com>
- Added in the pyrixs chipset fix for stable PCI DMA xfer
  so things like udma5 burst xfers across bus masters will
  work without locking up sx/lx 164 alpha's

* Fri May 18 2001 Arjan van de Ven <arjanv@redhat.com>
- bugfixes from 2.4.4-ac10

* Thu May 17 2001 Bill Nottingham <notting@redhat.com>
- add qla2x00 v4.28
- revert tlb-shootdown portion of -ac patch for ia64

* Thu May 17 2001 Arjan van de Ven <arjanv@redhat.com>
- compaq raid update now for all archs
- new e100 / e1000 / megaraid drivers


* Wed May 16 2001 Arjan van de Ven <arjanv@redhat.com>
- Fix Dell Poweredge 8450 patch

* Tue May 15 2001 Benjamin LaHaise <bcrl@redhat.com>
- replace reservation patch with vmfixes for a few vm deadlocks with highmem

* Tue May 15 2001 Arjan van de Ven <arjanv@redhat.com>
- Added Dell Poweredge 8450 patch
- Disable weird fixup for intel 450nx chipset

* Mon May 14 2001 Arjan van de Ven <arjanv@redhat.com>
- fixed bugfixes from 2.4.4-ac9
- discourage IRQ 12 for yenta_socket

* Fri May 11 2001 Arjan van de Ven <arjanv@redhat.com>
- Made ECN default to off and enabled CONFIG_INET_ECN

* Fri May 11 2001 Philip Copeland <bryce@redhat.com>
- no need for %ifdef'ing ipvs anymore

* Thu May 10 2001 Bill Nottingham <notting@redhat.com>
- add update for uhci driver on ia64

* Thu May 10 2001 Michael K. Johnson <johnsonm@redhat.com>
- disable reservation patch for now, not quite cooked yet.

* Thu May 10 2001 Benjamin LaHaise <bcrl@redhat.com>
- updated reservation patch.  should work now.

* Thu May 10 2001 Arjan van de Ven <arjanv@redhat.com>
- Added Al Viro's audit patches
- More drives for the blacklist 
- removed finer-flush patch

* Thu May 10 2001 Michael K. Johnson <johnsonm@redhat.com>
- Added CD-532E-A to the ide dma blacklist

* Wed May 09 2001 Benjamin LaHaise <bcrl@redhat.com>
- added memory reservation

* Wed May 09 2001 Bill Nottingham <notting@redhat.com>
- new ia64 patch (based on 2.4.4, so back a couple bits out)

* Wed May 09 2001 Arjan van de Ven <arjanv@redhat.com>
- Added patch for serialport on xircom cardbus
- Merged bugfixes from 2.4.4-ac6

* Tue May 08 2001 Michael K. Johnson <johnsonm@redhat.com>
- Add headers for athlon smp to merged symbol set
- Revert the dead swap patch from -ac12

* Tue May 08 2001 Bill Nottingham <notting@redhat.com>
- new smartarray stuff from Compaq (ia64-only ATM)

* Tue May 08 2001 Arjan van de Ven <arjanv@redhat.com>
- Bugfixes from 2.4.4-ac4 and 2.4.4-ac5
- Updated 8139too
- Fixed 8x registration bug in eepro
- Update gdth driver
- added fix for brlocks

* Mon May 07 2001 Michael K. Johnson <johnsonm@redhat.com>
- added linux-2.4.3-r128-drm-do-wait-for-fifo.patch

* Fri May 04 2001 Michael K. Johnson <johnsonm@redhat.com>
- Added Dell patch to be able to specify rebooting from boot cpu with "s" flag
- updated linux-2.4.3-ymfpci.patch to include niph patch from Pete Zaitcev
- updated linux-2.4.3-usb.patch to include dereg patch from Pete Zaitcev

* Fri May 4 2001 Benjamin LaHaise <bcrl@redhat.com>
- remove linux-2.4.3-smpcall-fix.patch

* Fri May 4 2001 Stephen C. Tweedie <sct@redhat.com>
- Fix race in smp_call_function

* Thu May 3 2001 Stephen C. Tweedie <sct@redhat.com>
- bump version number

* Thu May 3 2001 Philip Copeland <bryce@redhat.com>
- Added in submitted patch for the nautilus alpha system
  from Hyung Min SEO <HMSEO@sec.samsung.com>

* Thu May 3 2001 Stephen C. Tweedie <sct@redhat.com>
- allow urgent VM page allocation requests to be satisfied more
  easily

* Thu May 3 2001 Stephen C. Tweedie <sct@redhat.com>
- added significant speedup for scanning full swap maps

* Wed May 2 2001 Stephen C. Tweedie <sct@redhat.com>
- added trivial host-cpu sysrq-T debug output

* Wed May 2 2001 Benjamin LaHaise <bcrl@redhat.com>
- added linux-2.4.3-page_table_races.patch vm fixups

* Wed May  2 2001 Bill Nottingham <notting@redhat.com>
- don't call tty_write_message on unaligned traps on ia64

* Wed May 2 2001 Arjan van de Ven <arjanv@redhat.com>
- Added irq-fault lockup patch 
- Merged 2.4.4-ac3 bugfixes:
  - USB acm
  - APM allow_ints option
  - Descriptortable corruption
  - DMFE driver skb alloc  
  - typo in IDE code
  - netfilter updates
  - core network updates
  - via workaraound 686a fix
  - Alpha fixes


* Wed May 2 2001 Philip Copeland <bryce@redhat.com>
- added in DaveM's ALI patch for the sparc, with luck it may
  even work for the alpha

* Tue May 1 2001 Benjamin LaHaise <bcrl@redhat.com>
- added linux-2.4.3-smpcall-fix.patch to fix a rare deadlock

* Tue May 1 2001 Arjan van de Ven <arjanv@redhat.com>
- attempt DMA livelock fix

* Mon Apr 30 2001 Arjan van de Ven <arjanv@redhat.com>
- Add patch to revert the "schedule fork'd first" patch in
  mainstream tree. It makes broken userspace show up too much.
  Also causes performance problems in some normal cases.
- fix via audio pci_enable_device
- added sct's fix to the per-cpu-pages patch

* Sun Apr 29 2001 Arjan van de Ven <arjanv@redhat.com>
- Prevent negative inode-used counts (aviro)

* Sat Apr 28 2001 Arjan van de Ven <arjanv@redhat.com>
- added patch to avoid recursing in deadlocks in create_bounce

* Fri Apr 27 2001 Benjamin LaHaise <bcrl@redhat.com>
- added linux-2.4.3-vmlockup.patch for testing

* Fri Apr 27 2001 Arjan van de Ven <arjanv@redhat.com>
- Added bcrl's highmem patch
- Removed bcrl's highmem patch
- Added Al Viro's sync_one patch
- Added a patch to add the "apic" commandline option for
  some broken motherboards

* Thu Apr 26 2001 Michael K. Johnson <johnsonm@redhat.com>
- Added linux-2.4.3-highmemthrottle.patch

* Thu Apr 26 2001 Arjan van de Ven <arjanv@redhat.com>
- fixed bug #37759
- updated ips (ServerRAID) to 4.72
- Added Al Viro's bufferrace patch

* Wed Apr 25 2001 Bill Nottingham <notting@redhat.com>
- add qla1280 cleanup patch

* Wed Apr 25 2001 Arjan van de Ven <arjanv@redhat.com>
- Merged to ac14
- Added IPv6 patch (DaveM)

* Mon Apr 23 2001 Arjan van de Ven <arjanv@redhat.com>
- Added IRIX NFS Patch
- Added Ingo's swap patch

* Sun Apr 22 2001 Pete Zaitcev <zaitcev@redhat.com>
- Added a patch to restore my khubd fix over that official one.
  I think the official fix is no good, while ours is tested.
- Applied patch 271 again (with duplicated pieces removed).
- Added a patch for iForce joystick (#37075).

* Sun Apr 22 2001 Arjan van de Ven <arjanv@redhat.com>
- 2.4.3-ac12 (for the PDC oops and the DVD bugfixes)
- added "apm=allowints" kernel option for suspend problems,
  made this the default for IBM laptops

* Sat Apr 21 2001 Arjan van de Ven <arjanv@redhat.com>
- 2.4.3-ac11

* Fri Apr 20 2001 Bill Nottingham <notting@redhat.com>
- revert CDROM changes from ac10

* Fri Apr 20 2001 Arjan van de Ven <arjanv@redhat.com>
- fixed (hopefully) bouncebufferheads deadlock
- change reboot-behavior of Dell PE1300's

* Thu Apr 19 2001 Pete Zaitcev <zaitcev@redhat.com>
- fix for ymfpci buzzing (#29562).

* Thu Apr 19 2001 Philip Copeland <bryce@redhat.com>
- added in patch to fix a subtle 21143 autonegotiation problem
  The driver would claim to negotiate 100-FD, but would report
  late collisions and bad transmit throughput.

* Thu Apr 19 2001 Michael K. Johnson <johnsonm@redhat.com>
- cleaned up spec file a bit

* Thu Apr 19 2001 Arjan van de Ven <arjanv@redhat.com>
- added fix for FTP exploit
- merged to -ac10

* Wed Apr 18 2001 Arjan van de Ven <arjanv@redhat.com>
- upgraded to 2.4.3-ac9

* Tue Apr 17 2001 Bill Nottingham <notting@redhat.com>
- update ia64 to 010405 & sync

* Tue Apr 17 2001 Arjan van de Ven <arjanv@redhat.com>
- Updated to 2.4.3-ac7
- merged Pete Zaitcev's USB bugfix-patches

* Mon Apr 09 2001 Arjan van de Ven <arjanv@redhat.com>
- Added IDE corruption fix

* Sun Apr 08 2001 Michael K. Johnson <johnsonm@redhat.com>
- Update release to 2.4.2-2
- Clean up some cruft in spec file
- Relax ordering requirements: gawk used in postun
- Strengthen ordering requirements: now prereq correct initscripts
  for mkkerneldoth (read: "make kernel dot h")

* Sun Apr 08 2001 Doug Ledford <dledford@redhat.com>
- Fix some multipath issues (multipath-fixes-4)

* Sun Apr 08 2001 Arjan van de Ven <arjanv@redhat.com>
- Updated Xircom not-a-Tulip driver

* Sat Apr 07 2001 Doug Ledford <dledford@redhat.com>
- Hopefully the final round of i810 audio fixes

* Sat Apr 07 2001 Benjamin LaHaise <bcrl@redhat.com>
- extracted linux-2.4.2-page_bitmap.patch from vmpoison
  and added to all builds.

* Sat Apr 07 2001 Arjan van de Ven <arjanv@redhat.com>
- Hopefully fixed the /boot/kernel.h issue forever
- Silence a few more printk's to be syslog only

* Sat Apr  7 2001 Matt Wilson <msw@redhat.com>
- disable debugging
- 0.1.51

* Sat Apr  7 2001 Ingo Molnar <mingo@redhat.com>
- added swap fixes

* Sat Apr  7 2001 Ingo Molnar <mingo@redhat.com>
- ext2fs corruption fixes

* Fri Apr 06 2001 Bill Nottingham <notting@redhat.com>
- more ia64 csum tweaks

* Fri Apr 06 2001 Doug Ledford <dledford@redhat.com>
- fix the multipath code and re-enable

* Thu Apr 05 2001 Michael K. Johnson <johnsonm@redhat.com>
- Conditionalize multipath, disabled for now

* Thu Apr 05 2001 Arjan van de Ven <arjanv@redhat.com>
- Added bcrl's patch to fix SMP swap corruption

* Thu Apr 05 2001 Doug Ledford <dledford@redhat.com>
- fix i810 sound driver to work around broken artsd and a kernel bug

* Wed Apr 04 2001 Arjan van de Ven <arjanv@redhat.com>
- Added fixes for corruption in buffer.c and scsi_merge

* Wed Apr 04 2001 Michael K. Johnson <johnsonm@redhat.com>
- conflict with old versions of mount and nfs-utils

* Tue Apr 03 2001 Arjan van de Ven <arjanv@redhat.com>
- added ohci patch

* Tue Apr 03 2001 Ingo Molnar <mingo@redhat.com>
- TUX-fixes patch, update to -X4 version.

* Fri Mar 30 2001 Bill Nottingham <notting@redhat.com>
- fix ia64 build

* Thu Mar 29 2001 Bill Nottingham <notting@redhat.com>
- add patch to fix machine checks on ia64 (<asit.k.mallick@intel.com>)

* Wed Mar 28 2001 Benjamin LaHaise <bcrl@redhat.com>
- added linux-2.4.2-dma-livelock-fix

* Wed Mar 28 2001 Benjamin LaHaise <bcrl@redhat.com>
- added linux-2.4.2-vmtruncate.patch

* Wed Mar 28 2001 Stephen C. Tweedie <sct@redhat.com>
- Added aggressive reclaim of orphaned swap (if vmbalance enabled)

* Wed Mar 28 2001 Arjan van de Ven <arjanv@redhat.com>
- Added Alan's cardbus patch
- Added zaitcev's USB message throttling

* Wed Mar 28 2001 Benjamin LaHaise <bcrl@redhat.com>
- added BUG() if buffer unlocked in end_io call to vmpoison patch
- added linux-2.4.2-rqdebug.patch from sct.

* Wed Mar 28 2001 Ingo Molnar <mingo@redhat.com>
- another batch of multipath-fixes, separate patch so that
  we have an easy way back.

* Tue Mar 27 2001 Benjamin LaHaise <bcrl@redhat.com>
- added BUG() if buffer unlocked in end_io call to vmpoison patch

* Tue Mar 27 2001 Stephen C. Tweedie <sct@redhat.com>
- fix debugging conflict with smbfs internal debugging

* Tue Mar 27 2001 Tim Waugh <twaugh@redhat.com>
- added linux-2.4.2-restorestate.patch: fix bug #31170

* Tue Mar 27 2001 Benjamin LaHaise <bcrl@redhat.com>
- fix debugging bug with reclaim_page

* Tue Mar 27 2001 Arjan van de Ven <arjanv@redhat.com>
- Added Alan's "blacklist KT7RAID for IDE DMA" patch

* Tue Mar 27 2001 Benjamin LaHaise <bcrl@redhat.com>
- updated linux-2.4.2-no_profile.patch to correct patch
- updated linux-2.4.2-vmpoison.patch to fix a bug

* Mon Mar 26 2001 Benjamin LaHaise <bcrl@redhat.com>
- added linux-2.4.2-find_page.patch: potential corruption fix
- added linux-2.4.2-no_profile.patch regain 6MB of memory on boot
- added linux-2.4.2-bootmem_oom.patch to panic on oom during boot
- updated linux-2.4.2-vmpoison.patch with more poison, removed
  linux-2.4.2-uptodate.patch
- added linux-2.4.2-i2oinit.patch from Arjan

* Mon Mar 26 2001 Bill Nottingham <notting@redhat.com>
- patch from David Mosberger to fix networking issues on ia64

* Mon Mar 26 2001 Arjan van de Ven <arjanv@redhat.com>
- Mark OSB4 driver experimental
- Update TUX2
- merged zaitcev's OV511 fix
- disabled dma66 for all via IDE chipsets

* Sun Mar 25 2001 Benjamin LaHaise <bcrl@redhat.com>
- Added linux-2.4.2-uptodate.diff to BUG() out on page cache misuse;
  also includes a potential fix for the corruption problem.

* Sun Mar 25 2001 Ingo Molnar <mingo@redhat.com>
- Update the multipath-fixes patch to the much less
  radical C0 version, B1 was never meant to be committed,
  it was a Dell-only test-patch!

* Sat Mar 24 2001 Stephen C. Tweedie <sct@redhat.com>
- Added buffer_head highmem fix

* Fri Mar 23 2001 Benjamin LaHaise <bcrl@redhat.com>
- added linux-2.4.2-aviro-buffer.c.patch
- updated linux-2.4.2-vmpoison.patch

* Fri Mar 23 2001 Doug Ledford <dledford@redhat.com>
- Update the multipath-fixes patch to the B1 version from Ingo

* Fri Mar 23 2001 Arjan van de Ven <arjanv@redhat.com>
- Merged bugfixes from 2.4.2-ac23
  * isapnp fix
  * reiserfs corruption
  * sound lock_kernel thinkos
  * allow sleeping in C-A-D handlers
  * small PPP race


* Thu Mar 22 2001 Bill Nottingham <notting@redhat.com>
- merge in 010321 ia64 patch from David Mosberger
- don't apply vmpoison.patch on ia64 (it relies on per-cpu-pages)

* Thu Mar 22 2001 Benjamin LaHaise <bcrl@redhat.com>
- added linux-2.4.2-req_finished_io.patch for req_finished_io
- updated vmpoison.patch to fix a kmap problem
- added linux-2.4.2-ip_conntrack.patch to fix a hash table
  size of 0 which results in an Oops on startup
- added linux-2.4.2-pmd_alloc_fix.patch
- added linux-2.4.2-bootmem.patch to fix an off by one error
  that results in memory overwrites

* Thu Mar 22 2001 Arjan van de Ven <arjanv@redhat.com>
- Added patch from DaveM to fix IPv6 tunnels.
- Merged tux V1
- Disabled the Serverworks UDMA support
- Added IBM's new ServerRAID driver. This one has survived lots of testing
    by IBM
- Added ptrace patch

* Wed Mar 21 2001 Philip Copeland <bryce@redhat.com>
- Updated config files to take account of two new config options
  CONFIG_IP_VS_DEBUG (n)
  CONFIG_IP_VS_TAB_BITS (16)
- Modified the 2.4.2-cipe.patch to acomodate the change of location
  of ipvs

* Wed Mar 21 2001 Philip Copeland <bryce@redhat.com>
- retired Patch275 and replaced it with 276 on the recomendation of
  Wensong which moves ipvs from 0.1.2 -> 0.2.4
  Structurally removes net/ipv4/netfilter/ip_vs and moves it to
  net/ipv4/ipvs

* Wed Mar 21 2001 Doug Ledford <dledford@redhat.com>
- fix memory leak in i810 sound driver
- update scsi-reset patch to correct some locking issues under heavy reset
  conditions (James Bottomley)

* Wed Mar 21 2001 Stephen C. Tweedie <sct@redhat.com>
- Added shared memory locking fix

* Wed Mar 21 2001 Arjan van de Ven <arjanv@redhat.com>
- silenced DRI debugging messages
- merged Ingo's patch for spinlocks around apic operations

* Wed Mar 21 2001 Doug Ledford <dledford@redhat.com>
- update i810 sound driver to solve artsd output problems
- added scsi_scan patch to make scanning of sparselun devices work again
- update old aic7xxx driver to possibly fix 7896 lockup problems
- updated new aic7xxx driver to version 6.1.7

* Tue Mar 20 2001 Arjan van de Ven <arjanv@redhat.com>
- Added patch for netgear fa31x boards powerstate
- Added patch to silence PS/2 code (no keyboard there if
  there is a USB keyboard)

* Mon Mar 19 2001 Arjan van de Ven <arjanv@redhat.com>
- Added Zaitcev's patch for USB mice (#23670)


* Sun Mar 18 2001 Arjan van de Ven <arjanv@redhat.com>
- Added fix for HPT370 UDMA problem

* Fri Mar 16 2001 Michael K. Johnson <johnsonm@redhat.com>
- Added qlogicfc to the list of controllers with limited scsi request sizes

* Thu Mar 15 2001 Michael K. Johnson <johnsonm@redhat.com>
- updated binfmt_misc patch to create directory

* Thu Mar 15 2001 Benjamin LaHaise <bcrl@redhat.com>
- added linux-2.4.2-ac20-pmd_alloc.diff fix for PAE

* Thu Mar 15 2001 Arjan van de Ven <arjanv@redhat.com>
- Added Al Viro's patch to fs/namei.c
- Added the BKL patch for truncate (2.4.2-ac)
- added VM poison

* Wed Mar 14 2001 Arjan van de Ven <arjanv@redhat.com>
- Added 2.4.2-ac20 I2O patches
- Made PCI printk's KERN_INFO

* Thu Mar 13 2001 Stephen C. Tweedie <sct@redhat.com>
- merge in VM performance changes up to 2.4.2-ac18

* Tue Mar 13 2001 Arjan van de Ven <arjanv@redhat.com>
- fix bug 30513 (iostat vs promise IDE boards)
- TUX 2.4.2-S4
- merged md fixes

* Mon Mar 12 2001 Bill Nottingham <notting@redhat.com>
- run /usr/sbin/module_upgrade in a kudzu trigger as well

* Mon Mar 12 2001 Arjan van de Ven <arjanv@redhat.com>
- merged bugfixes from 2.4.2-ac18:
  - reiserfs cleanup
  - zerocopy bugfixes
  - zerocopy nbd
  - smbfs fixes
  - cyrix III MTRR checks
  - vmalloc race fix
  - pcmcia resource fix
- merged TUX 2.4.2-P3
- new version of the xircom driver
- default limit of 64 sectors in a scsi request
- enabled slab poison
- fixed 28489

* Fri Mar 09 2001 Michael K. Johnson <johnsonm@redhat.com>
- Added another request-size limiting patch for Qlogic sbus and BusLogic,
  may need to add more adapters to this patch over time

* Fri Mar 09 2001 Arjan van de Ven <arjanv@redhat.com>
- Added QLogic ISP request-size limiting patch
- Updated xircom_cb driver to newer version
- Potential workaround for Abit KT7ARAID board bugs in via-corruption patch

* Thu Mar 08 2001 Michael K. Johnson <johnsonm@redhat.com>
- Added cipefix patch from David Miller

* Thu Mar 08 2001 Stephen C. Tweedie <sct@redhat.com>
- add current raw IO fixes

* Thu Mar 08 2001 Pete Zaitcev <zaitcev@redhat.com>
- Adding a fix for usb-uhci to work when SLAB is not aligned (poisoned).

* Thu Mar 08 2001 Michael K. Johnson <johnsonm@redhat.com>
- now prereq modutils 2.4.2-5 for new binfmt_misc support

* Thu Mar 08 2001 Arjan van de Ven <arjanv@redhat.com>
- added Ingo's bouncebuffer patch
- added Tim Waughs parport fixes
- switched to Alan's cleaned up megaraid
- added zaitcev's patch to prevent LVM oops
- added Than Ngo's patch for pcmcia ISDN
- forward-ported 2.2.19pre1 via timerbug workaround
- added Al Viro's binfmt_misc

* Wed Mar 07 2001 Arjan van de Ven <arjanv@redhat.com>
- added epca patch and more USB scanner ID's from 2.4.2-ac13
- added the IDE dma blacklist

* Tue Mar 06 2001 Doug Ledford <dledford@redhat.com>
- heavily patched/modified version of the i810 audio driver

* Tue Mar 06 2001 Arjan van de Ven <arjanv@redhat.com>
- added pge patch for Cyrix 686 kernels from Arjan

* Tue Mar 06 2001 Michael K. Johnson <johnsonm@redhat.com>
- depmod -ae

* Tue Mar 06 2001 Arjan van de Ven <arjanv@redhat.com>
- 2 more patches from 2.4.2-ac11/12 (8139too and the pci resources API change )
- workaround for the tokenring init mess
- added patch to enable the second IDE channel on PDC20265's

* Tue Mar  6 2001 Matt Wilson <msw@redhat.com>
- added linux-2.4.2-i2o-blocksize.patch (Patch225) to fix i2o /proc/partitions
  entries

* Mon Mar 05 2001 Michael K. Johnson <johnsonm@redhat.com>
- Turned off CONFIG_USB_MOUSE because the HID code handles all mice we know

* Mon Mar 05 2001 Arjan van de Ven <arjanv@redhat.com>
- Added the patch from DHinds to fix cardbus irqs
- enabled multicast routing, bridging and QOS
- merged patches 214 to 224 from 2.4.2-ac11


* Sun Mar 4 2001 Philip Copeland <bryce@redhat.com>
- Reverted the parport_device_id changes that are in ac3
  which prevent the kernel-sources-x.y.z.src.rpm from
  being recompiled

* Fri Mar 02 2001 Ingo Molnar <mingo@redhat.com>
- linux-2.4.2-nmi-lockup-workaround.patch temporarily defaults nmi watchdog off

* Fri Mar 02 2001 Philip Copeland <bryce@redhat.com>
- added linux-2.4.2-alpha-irongate.patch from Compaq

* Fri Mar 02 2001 Michael K. Johnson <johnsonm@redhat.com>
- added Arjan's linux-2.4.2-via-corruption.patch to fix disk corruption
  problems widely reported on KT133 machines
- Stephen/Tim fixed linux-2.4.1-axboe-scsi-max-sec.patch fixing scsi performance

* Thu Mar 01 2001 Doug Ledford <dledford@redhat.com>
- Added the scsi-reset patch so that you can reset devices through their
  sg entry

* Thu Mar 01 2001 Arjan van de Ven <arjanv@redhat.com>
- updated reiserfs to latest version
- prevent raid from oopsing
- lockd patch
- added alternate airo_cs driver
- added zaitcev's USB alloc fix

* Wed Feb 28 2001 Michael K. Johnson <johnsonm@redhat.com>
- atp.c would not compile as a module, fixed

* Wed Feb 28 2001 Arjan van de Ven <arjanv@redhat.com>
- Added extra Toshoboe PCI ID (29993)
- added "fix hang in parport" patch (twaugh)
- maestro3 DMA fix
- fixed 29908 (loopdevice oops)

* Tue Feb 27 2001 Matt Wilson <msw@redhat.com>
- added a patch to fix for non-atomic bit clear in eepro100 driver on alpha
  (linux-2.4.2-eepro100-alpha.patch)

* Tue Feb 27 2001 Arjan van de Ven <arjanv@redhat.com>
- updated ikd to 2.4.2
- added olympic driver fix
- make Alpha happy
- added opl3sa patch
- added netdevice setup patch
- added 3ware patch
- merged TUX version G9
 
* Mon Feb 26 2001 Doug Ledford <dledford@redhat.com>
- bug fix to the aic7xxx-5.2.3 driver
- Added Michael E. Brown <michael_e_brown@dell.com> patch to add an ioctl to
  the block device layer to allow accessing the last sectors in a block
  device that has an odd number of sectors (needed for EFI compliance)
- Added Ingo's multipath I/O support for the md raid layer

* Mon Feb 26 2001 Bill Nottingham <notting@redhat.com>
- fix a case where the ia64 clock can go backwards (from <steiner@sgi.com>)

* Mon Feb 26 2001 Arjan van de Ven <arjanv@redhat.com>
- Added netdebug patch on DaveM's request
- Added support for the Epson 1240U usb scanner
- removed wavelan udelay patch (no longer needed for gcc 2.96-74)
- derace the waking of the usb storage thread
- merged to 2.4.2-ac3, bumped version to 0.1.15
- put in the new, experimental xircom_cb driver
- upgraded to tux 2.4.2-F8

* Fri Feb 23 2001 Michael K. Johnson <johnsonm@redhat.com>
- added preinstalls for smp and enterprise to modprobe loop like uniprocessor
- disabled 3c90x driver because it does not work correctly.

* Fri Feb 23 2001 Bill Nottingham <notting@redhat.com>
- just remove modules.* in %preun; catches anything new, and
  avoids errors if certain files aren't there

* Fri Feb 23 2001 Arjan van de Ven <arjanv@redhat.com>
- Updated 3c59x driver to version 1.1.14 from Andrew Morton
- enabled Hewlett-Packard 8200e/8210e CD-Writer Plus
- enabled Advanced routing (#29087)

* Tue Feb 22 2001 Matt Wilson <msw@redhat.com>
- updated module-info to the copy from anaconda CVS

* Thu Feb 22 2001 Arjan van de Ven <arjanv@redhat.com>
- added 3ware patch
- re-enabled 3ware again

* Thu Feb 22 2001 Michael K. Johnson <johnsonm@redhat.com>
- added linux-2.4.1-flush_tlb_export.patch
- updated to e100 1.5.5

* Wed Feb 21 2001 Doug Ledford <dledford@redhat.com>
- update Justin Gibbs' aic7xxx driver to version 6.1.4

* Wed Feb 21 2001 Bill Nottingham <notting@redhat.com>
- export a couple more symbols on ia64
- increase default size of swiotlb on ia64

* Wed Feb 21 2001 Michael K. Johnson <johnsonm@redhat.com>
- disable 3ware driver on SMP until a bugfix is found
- updated to tux2-2.4.1-P5 to fix dcache bug

* Wed Feb 21 2001 Arjan van de Ven <arjanv@redhat.com>
- Merged bugfixes from ac20:
  - non-PNP AWE32 fix
  - updates to various pcmcia network drivers
- Added "ideX=nodma" commandline option

* Tue Feb 20 2001 Arjan van de Ven <arjanv@redhat.com>
- Reordered several patches to the proper section
- Merged the following patches from ac17-18-19:
  - jgarzik's network driver cleanups
  - reiserfs tailpacking datacorruption
  - smbfs off-by-one fixes
  - USB 2.0, USB Hub device claim race, USB net recovery 
  - SO_SNDTIMEO bugs
- Fixed CIPE on SMP machines (#28386)
- new tulip driver
- new version of the Loop fixes (Al Viro)
- backed out vm-rebalance; be careful with ext2
  
* Mon Feb 19 2001 Bill Nottingham <notting@redhat.com>
- minor ia64 tweaks

* Mon Feb 19 2001 Michael K. Johnson <johnsonm@redhat.com>
- removed duplicate ksyms exports for alpha
- added brokenmptable patch from Ingo
- Turned on CONFIG_USB_MOUSE and CONFIG_USB_KBD because they
  are needed after all with some hardware and the conflicts with 
  CONFIG_USB_HID are non-fatal.

* Mon Feb 19 2001 Arjan van de Ven <arjanv@redhat.com>
- Merged tulip PNIC updates from 2.4.1-ac18
- removed extra DSCC4=m config option
- changed to the EUI64 format for IPv6
- enlarged printk buffer (#28288)
- upgraded to ac16, bump to 0.1.11

* Fri Feb 16 2001 Arjan van de Ven <arjanv@redhat.com>
- actually commited NFS patch
- updated intel e1000 to version 3.0.7
- reverted the kudzu change
- actually build the HP5300 module
- provisional WinChip patch
- made the 2.4 kernel conflict with isapnptools as that conflict
  breaks the actual PNP in the 2.4 kernel.


* Thu Feb 15 2001 Arjan van de Ven <arjanv@redhat.com>
- NFS memcmp bug
- changed requires kudzu >= 0.93 to conflicts kudzu <= 0.92
- made the kernel conflict with program too old according
  to Documentation/Changes

* Thu Feb 15 2001 Bill Nottingham <notting@redhat.com>
- change wvlan_cs Config.in description to something more appropriate

* Thu Feb 15 2001 Michael K. Johnson <johnsonm@redhat.com>
- Turned off CONFIG_USB_MOUSE and CONFIG_USB_KBD because they
  conflict with using CONFIG_USB_HID (hotplug loads both...)
- build toshiba module

* Thu Feb 15 2001 Karsten Hopp <karsten@redhat.de>
- search for all LUNs on CR3500 shared SCSI controller

* Wed Feb 14 2001 Doug Ledford <dledford@redhat.com>
- Add Justin Gibbs' aic7xxx driver version 6.1.1 as aic7xxx_new

* Wed Feb 14 2001 Michael K. Johnson <johnsonm@redhat.com>
- added quiet patch so that autorun and magicdev don't mangle logs

* Wed Feb 14 2001 Arjan van de Ven <arjanv@redhat.com>
- Made Cyrix CPU's work again
- Added ideprobe patch to avoid hotprobe lockups
- fixed tulip xircom phase 2
- ikd (kdb)
- remove *~ files (#18751)
- fix poll() on usb printers (#26909)
- fixed argument parsing for sym63c416 driver
- merged ac13 patch to prevent parport from corrupting the pci dev list
- fixed sbpcd (ac13)
- fixed usbhub (ac13, missing unlock_kernel)
- fixed vmalloc race (ac13)
- potential uhci slab interaction fix
- smbfs fixes (ac13)
- tmpfs nlink fix for perl (ac13)
- arcnet init fixes (ac13)


* Wed Feb 14 2001 Matt Wilson <msw@redhat.com>
- 0.1.8
- turn off tux

* Tue Feb 13 2001 Bill Nottingham <notting@redhat.com>
- fix typos in debugging patch

* Tue Feb 13 2001 Michael K. Johnson <johnsonm@redhat.com>
- turned off CONFIG_BLK_DEV_ALI15X3 for alpha
- updated to tux2-2.4.1-L4, merge with debugging and highmem patches
- added %debugging macro for turning debugging on and off
- updated to scsi-max-sec-2

* Tue Feb 13 2001 Matt Wilson <msw@redhat.com>
- 0.1.6
- turned off CONFIG_NETFILTER and CONFIG_FILTER in i386 BOOT config
- modified linux-2.4.1-ia64-010131-2.diff to use the new PCI_ROUTING_TABLE
  structure in acpiconf.c

* Tue Feb 13 2001 Arjan van de Ven <arjanv@redhat.com>
- Made "realmode poweroff" a commandline option disabled by default.
  (believed to fix #26261, #26760, #24198, #23322)
- disabled netfilter and such in the -BOOT option
- made the kernel slab patch a config-option disabled for BOOT
- ServerRAID 4.50

* Tue Feb 13 2001 Matt Wilson <msw@redhat.com>
- 0.1.5
- regenerated linux-2.4.1-ia64-010131-2.diff so it will patch
- specify ARCH= when building the common sparc/sparc64 headers

* Mon Feb 12 2001 Michael K. Johnson <johnsonm@redhat.com>
- added Jens Axboe's scsi-max-sec-1 as linux-2.4.1-axboe-scsi-max-sec.patch
- updated to new aacraid driver (depends on Jens's patch) plus Matt Domsch's fix
- added changeloop-fixes-2 from Al

* Mon Feb 12 2001 Arjan van de Ven <arjanv@redhat.com>
- upgraded to 2.4.1-ac10
- merged new e100/e1000 drivers

* Sat Feb 10 2001 Matt Wilson <msw@redhat.com>
- disable broken sparcaudio drivers on sun4[cdm]
- disable reiserfs on all sparc
- added linux-2.4.1ac8-nopci.patch to correct builds if not using CONFIG_PCI
- added linux-2.4.1ac8-zap_page_range.patch

* Fri Feb 09 2001 Michael K. Johnson <johnsonm@redhat.com>
- updated to Al's latest loop fixes

* Fri Feb 9 2001 Arjan van de Ven <arjanv@redhat.com>
- updated to 2.4.1-ac8, changed version number to 0.1.1
- added Ingo's highmem patch
- added IRC netfilter addon for DCC over NAT
- new megaraid driver (1.14g)
- Fix for bug 26696 (compaq vs irq 13)

* Thu Feb  8 2001 Bill Nottingham <notting@redhat.com>
- sync up ia64 with David Mosberger's 20010131 patch
- add x86-compatibility ia64 bugfix patch from Don Dugger

* Thu Feb  8 2001 Matt Wilson <msw@redhat.com>
- added linux-2.4.1-i2o-lockup.patch for some bus/card combos

* Thu Feb  8 2001 Bill Nottingham <notting@redhat.com>
- don't buildprereq gcc-2.96-74 on ia64

* Thu Feb 8 2001 Arjan van de Ven <arjanv@redhat.com>
- updated to 2.4.1-ac6, changed version number
- new broadcom driver
- serverworks workaround

* Wed Feb 7 2001 Arjan van de Ven <arjanv@redhat.com>
- corruption fix
- merged xircom_tulip into real tulip
- require gcc 2.96-74 or later for building
- merged aic7xxx from HEAD
- added DAC960 version 2.4.10

* Wed Feb 07 2001 Michael K. Johnson <johnsonm@redhat.com>
- use module_upgrade from kudzu package, prerequire kudzu >= 0.93

* Wed Feb  7 2001 Doug Ledford <dledford@redhat.com>
- fix the aic7xxx_new-6.1.0 patch :-(
- fix the aic7xxx_new-6.1.0 patch again :-(

* Wed Feb  7 2001 Matt Wilson <msw@redhat.com>
- added linux-2.4.1-i2o.patch.  This registers i2o block devices in
  /proc/partitions and fixes some other i2o bugs.

* Tue Feb 06 2001 Michael K. Johnson <johnsonm@redhat.com>
- require modutils 2.4.2 or greater

* Tue Feb  6 2001 Bernhard Rosenkraenzer <bero@redhat.com>
- Update devfsd to 1.3.11, fixes some glibc 2.2 issues

* Tue Feb  6 2001 Doug Ledford <dledford@redhat.com>
- update the aic7xxx driver to 5.2.2
- move the new Adaptec aic7xxx driver to aic7xxx_new

* Tue Feb  6 2001 Matt Wilson <msw@redhat.com>
- add a buildjensen macro, set it to 0 (as jensen seems broken)

* Mon Feb  5 2001 Matt Wilson <msw@redhat.com>
- 0.99.23
- make jensen subpackage on alpha (again, yuck)

* Mon Feb  5 2001 Matt Wilson <msw@redhat.com>
- 0.99.22
- turn on enterprise kernel
- set CONFIG_FILTER and CONFIG_NETFILTER to off in i386 BOOT kernel

* Mon Feb  5 2001 Arjan van de Ven <arjanv@redhat.com>
- Groundwork for the 2.4.1-ac2 merge
- turned of ACPI
 

* Mon Feb 5 2001 Arjan van de Ven <arjanv@redhat.com>
- added Matrox G450 patch
- updated from 2.4.1-ac1 to 2.4.1-ac2

* Fri Feb  2 2001 Matt Wilson <msw@redhat.com>
- tweaked the alpha boot kernel to be a little smaller
- moved the alpha header patch to if %%tux
- turn off tux
- added linux-2.4.0-alpha-header-conflict.patch
  (no more NFS root installs)

* Fri Feb 2 2001 Arjan van de Ven <arjanv@redhat.com>
- Socket DoS fix from Alexey/DaveM

* Thu Feb  1 2001 Bernhard Rosenkraenzer <bero@redhat.com>
- Add missing /etc/modules.devfs to devfsd package

* Thu Feb 01 2001 Michael K. Johnson <johnsonm@redhat.com>
- cciss 2.4.2
- integrated tested loop patches from Al

* Wed Jan 31 2001 Doug Ledford <dledford@redhat.com>
- added a fix for a PIII security hole

* Wed Jan 31 2001 Benjamin LaHaise <bcrl@redhat.com>
- added linux-2.4.1-zap_page_range_fix.patch

* Wed Jan 31 2001 Michael K. Johnson <johnsonm@redhat.com>
- new tux patch tux2-2.4.0-final-S9

* Wed Jan 31 2001 Arjan van de Ven <arjanv@redhat.com>
- Fixed3c575 driver load typo-bug (23820)
- fixed athlon build for tux
- added provisional ide-floppy patch
- silenced the ide-cs driver a bit (resource management conflict between IDE
  and PCMCIA subsystems)
- made ia64 almost build

* Wed Jan 31 2001 Bill Nottingham <notting@redhat.com>
- include include/pcmcia in kernel-source so pcmcia drivers can build 

* Tue Jan 30 2001 Michael K. Johnson <johnsonm@redhat.com>
- temporarily disabled Al's loopback patches while he fixes them

* Tue Jan 30 2001 Arjan van de Ven <arjanv@redhat.com>
- Fixed i82365 driver (bug 24804)
- added "athlon" architecture
- Phase 1 of ide-cs fix
- maestro3 patch from Zach Brown

* Mon Jan 29 2001 Doug Ledford <dledford@redhat.com>
- Updated aic7xxx driver to 6.1.0
- Corrected a bug in the rhconfig.h file we install
- Corrected a bug in the build process in the spec file

* Mon Jan 29 2001 Michael K. Johnson <johnsonm@redhat.com>
- new tux2 patch tux2-2.4.0-final-R9
- integrated Al's loopback device fixes
- since enterprise kernel has only highmem-64GB support, limit to >= PIII

* Sun Jan 28 2001 Michael K. Johnson <johnsonm@redhat.com>
- integrated Linus's shared memory swap patch
- integrated Andrey's 1.36 eepro100 driver
- integrated block scheduler fix from pre11
- updated to new tux2 patch, now modular

* Fri Jan 26 2001 Michael K. Johnson <johnsonm@redhat.com>
- added Jens Axboe's loop patch (disabled, Al fixing it and changeloop both)

* Fri Jan 26 2001 Arjan van de Ven <arjanv@redhat.com>
- Fixed parport_cs unresolved symbol
- reverted new wvlan port, the old one _did_ work

* Fri Jan 26 2001 Doug Ledford <dledford@redhat.com>
- added the xmm patch to keep the system from touching non-existent mxcsr
  registers
- verified that the two linux-merge-*.awk scripts do indeed use the right
  symbol names so that they should work properly

* Thu Jan 25 2001 Bill Nottingham <notting@redhat.com>
- remove /lib/modules/<whatever>/modules.generic_string as well (#24991)

* Thu Jan 25 2001 Michael K. Johnson <johnsonm@redhat.com>
- integrated new tux2 patch
- require new mkinitrd for RAID modules

* Thu Jan 25 2001 Arjan van de Ven <arjanv@redhat.com>
- Added parport_cs port from pcmcia-cs package
- backed out to ac10
- new wvlan port, this one is reported to work even

* Wed Jan 24 2001 Erik Troan <ewt@redhat.com>
- updated RAID_AUTORUN patch

* Wed Jan 24 2001 Arjan van de Ven <arjanv@redhat.com>
- Fix for bug 24698 (incorrect "build" link)
- Updated to 2.4.0-ac11 (still pre9 based), bumped version to 0.99.11
- added patch to fix most warnings people will see
- changes wvlan.o to wvlan_cs.o

* Tue Jan 23 2001 Matt Wilson <msw@redhat.com>
- 2.4.0-0.99.10, ac10 base
- rebuild with modutils 2.4.2 in place

* Tue Jan 23 2001 Matt Wilson <msw@redhat.com>
- added RAID_AUTORUN ioctl to raid driver from Ingo
- fixed the autorun patch

* Tue Jan 23 2001 Benjamin LaHaise <bcrl@redhat.com>
- IDE DMA by default enabled
- add lm_sensors built as modules
- enable reiserfs

* Tue Jan 23 2001 Arjan van de Ven <arjanv@redhat.com>
- blacklisted IBM deskstar disks for UDMA on hpt366 controllers (dwmw2)
- added RAID5 corruption fix from 2.4.1-pre10
- added fix for FD problem from 2.4.1-pre10
- added DAC960 fix from 2.4.1-pre10 (Jens Axboe's patch)
- added fix wrong __init in io-apic.c from 2.4.1-pre10
- removed broadcom driver temporarily

* Mon Jan 22 2001 Matt Wilson <msw@redhat.com>
- uncomment rm -rf $RPM_BUILD_ROOT from %clean
- modified the drivers/usb/uhci.c patch of the ia64 patch to patch against ac10
- resynced kernel-2.4.0-i386-BOOT.config with available options
- added linux-2.4.0-tgafb-unregister-framebuffer.patch to pass correct
  value into unregister_framebuffer
- updated kernel-2.4.0-ia64-smp.config and kernel-2.4.0-ia64.config for
  available options

* Mon Jan 22 2001 Benjamin LaHaise <bcrl@redhat.com>
- added linux-2.4.0-sysctl.patch
- added linux-2.4.0-map_user_kiobuf-fix.patch

* Mon Jan 22 2001 Matt Wilson <msw@redhat.com>
- increased ramdisk size of kernel-BOOT from 4096 to 4608

* Mon Jan 22 2001 Arjan van de Ven <arjanv@redhat.com>
- updated to ac10, which already contains the waitpid patch

* Mon Jan 22 2001 Benjamin LaHaise <bcrl@redhat.com>
- added linux-2.4.0-waitpid.patch to fix init/contextd SIGCHLD race

* Mon Jan 22 2001 Arjan van de Ven <arjanv@redhat.com>
- added first draft of wvlan driver
- touched the ide-cs thing. Please test

* Mon Jan 22 2001 Michael K. Johnson <johnsonm@redhat.com>
- turned on e1000 driver again
- e100 updated to 1.5.0 as linux-2.4.0-e100.patch

* Mon Jan 22 2001 Erik Troan <ewt@redhat.com>
- switched ide-cd back to a module in all x86 kernels

* Fri Jan 19 2001 Arjan van de Ven <arjanv@redhat.com>
- added Broadcom 5700 driver
- added patch to workaround gross misuse of ASSERT in IrDA

* Fri Jan 19 2001 Michael K. Johnson <johnsonm@redhat.com>
- Added aacraid driver (broken so added as a non-building placeholder)
- Turn off modules on Alpha that are not building correctly
- Turn off e100 driver on IA64 because it doesn't build there
- Added linux-2.4.0-ieee1394-queuefix.patch for task queue changes
- Added linux-2.4.0-3x90x.patch 3c90x driver from 3com

* Fri Jan 19 2001 Arjan van de Ven <arjanv@redhat.com>
- updated megaraid to 1.14b
- made the non-smp kernel provide "kernel = 2.4"
- made the smp kernels provide "module-info"

* Thu Jan 18 2001 Philip Copeland <bryce@redhat.com>
- added in the SARD patch

* Thu Jan 18 2001 Erik Troan <ewt@redhat.com>
- switched idefloppy to build in
- updated e100, e1000 driver
- enabled natsemi module in i386 BOOT kernel

* Thu Jan 18 2001 Michael K. Johnson <johnsonm@redhat.com>
- new tux patch
- turned on CONFIG_IP_NF_IRC as module

* Wed Jan 17 2001 Matt Wilson <msw@redhat.com>
- fixed typo in linux-2.4.0-aic7xxx-6.0.8BETA.patch for !i386 !alpha

* Wed Jan 17 2001 Bill Nottingham <notting@redhat.com>
- update to cipe-1.4.5, make it one patch

* Wed Jan 17 2001 Arjan van de Ven <arjanv@redhat.com>
- update to 2.4.0-ac9

* Tue Jan 16 2001 Bill Nottingham <notting@redhat.com>
- fix the aic7xxx patches to not patch backup files
- fix the cipe makefile so that it builds

* Mon Jan 15 2001 Doug Ledford <dledford@redhat.com>
- move the current aic7xxx driver aic7xxx_old
- add Justin Gibbs' new aic7xxx driver
- add a fix so that the cs4281 module will build

* Fri Jan 12 2001 Karsten Hopp <karsten@redhat.de>
- added starfire mmio patch to allow reload of this module

* Fri Jan 12 2001 Philip Copeland <bryce@redhat.com>
- Added in hooks for the ipvs 0.1.2 production kits to ksyms.c
- Added in patch250 to the spec file referancing linux-2.4.0-ipvs.patch
- added subdir ipvs in kernel tree which holds ipvs module code
- ac4 typo fix

* Fri Jan 12 2001 Michael K. Johnson <johnsonm@redhat.com>
- made build symlink relative
- qla1x160src-3.23Beta as linux-2.4.0-qla1280.patch
- make oldconfig_nonint so that builds reliably fail when config files need mods

* Thu Jan 11 2001 Bill Nottingham <notting@redhat.com>
- turn off CONFIG_DISABLE_VHPT on ia64, it's broken
- fix cs4281 makefile oops
- add new patch to possibly fix broken CONFIG_DISABLE_VHPT

* Thu Jan 11 2001 Karsten Hopp <karsten@redhat.de>
- moved e1000-2.5.11.patch and the update to 2.5.14 into one patch

* Thu Jan 11 2001 Michael K. Johnson <johnsonm@redhat.com>
- Moved back to static IDE for now because a couple machines had problems.
- qla1x160src-3.22Beta as linux-2.4.0-qla1280.patch
- megaraid 1.13s as linux-2.4.0-megaraid.patch

* Wed Jan 10 2001 Matt Wilson <msw@redhat.com>
- add free_dma and request_dma prototype in asm-ia64/dma.h as
  Patch58: linux-2.4.0-ia64-free_dma.patch
- remove Patch54: linux-2.4.0-test11-ia64-ksyms.patch
- remove Patch55: linux-2.4.0-test12-ia64-idesym.patch

* Wed Jan 10 2001 Bill Nottingham <notting@redhat.com>
- sync ia64 (010109 patch)

* Wed Jan 10 2001 Matt Wilson <msw@redhat.com>
- merged alpha .config files back to the way they need to be
- turn alpha back on

* Wed Jan 10 2001 Michael K. Johnson <johnsonm@redhat.com>
- update to 2.4.0-ac4
- pcmcia moved to its own package
- update to new tux patch
- e820 reporting from Arjan
- Andi's RAID5 xor fix
- Ingo's Athlon APIC fix

* Mon Jan  8 2001 Bill Nottingham <notting@redhat.com>
- remove ksymoops/kernel-utils

* Fri Dec 29 2000 Bill Nottingham <notting@redhat.com>
- fix up prereqs

* Wed Dec 27 2000 Bill Nottingham <notting@redhat.com>
- something is horribly, horribly wrong with modular SCSI on ia64; turn it off
- rename source RPM back to 'kernel'

* Fri Dec 22 2000 Erik Troan <ewt@redhat.com>
- updated pcmcia config file for 2.4 cardbus support

* Thu Dec 21 2000 Erik Troan <ewt@redhat.com>
- turned HOTPLUG on for i386 BOOT kernel (PCMCIA doesn't build w/o it)

* Tue Dec 19 2000 Michael K. Johnson <johnsonm@redhat.com>
- Added linux-2.4.0-test11-vidfail.patch and enabled it for the x86 BOOT kernel
- More USB support in x86 BOOT kernel
- Require new mkinitrd for IDE modules
- SCSI entirely modular

* Fri Dec 15 2000 Bill Nottingham <notting@redhat.com>
- add patch to fix unresolved symbol on ia64 in ide-probe-mod

* Wed Dec 13 2000 Michael K. Johnson <johnsonm@redhat.com>
- CONFIG_PARPORT_PC_FIFO off, bad default at this time

* Tue Dec 12 2000 Matt Wilson <msw@redhat.com>
- switch to un-TUXified kernel
- turn on framebuffer in the BOOT kernel

* Tue Dec 12 2000 Michael K. Johnson <johnsonm@redhat.com>
- New RC of TUX-1.01 patch

* Fri Dec 08 2000 Michael K. Johnson <johnsonm@redhat.com>
- CONFIG_HAPPYMEAL turned on for all architectures

* Thu Dec  7 2000 Bill Nottingham <notting@redhat.com>
- update ia64 patch to the 1206 version
- update e100, e1000 drivers

* Wed Dec 06 2000 Michael K. Johnson <johnsonm@redhat.com>
- Require fileutils for ln use in %post scripts
- Modular IDE

* Tue Dec 05 2000 Michael K. Johnson <johnsonm@redhat.com>
- Remove apa1480 driver temporarily for TUX build

* Mon Dec  4 2000 Bill Nottingham <notting@redhat.com>
- add patch to fix SWIOTLB from Asit Mallick

* Sun Dec  3 2000 Bill Nottingham <notting@redhat.com>
- turn on usb-uhci as well as uhci
- update megaraid to 1.13beta

* Thu Nov 30 2000 Michael K. Johnson <johnsonm@redhat.com>
- TUX 1.01 RC

* Wed Nov 29 2000 Bill Nottingham <notting@redhat.com>
- fix ia64 semaphore symbol problems
- fix cipe symbol problems

* Wed Nov 29 2000 Michael K. Johnson <johnsonm@redhat.com>
- TUX 1.01 integrated with test11

* Tue Nov 28 2000 Bill Nottingham <notting@redhat.com>
- make ia64 patch patch cleanly with test11

* Mon Nov 27 2000 Bill Nottingham <notting@redhat.com>
- remove all modules.<foo>map files on package removal

* Fri Nov 24 2000 Bill Nottingham <notting@redhat.com>
- add patch to fix FAT32, patch for alignment of unwind data

* Mon Nov 20 2000 Bill Nottingham <notting@redhat.com>
- make nfs a module

* Thu Nov 16 2000 Bill Nottingham <notting@redhat.com>
- new ia64 patch from David Mosberger
- make ppp a module
- allow glibc to build for the moment

* Fri Nov 10 2000 Bill Nottingham <notting@redhat.com>
- fix alpha build

* Thu Nov  9 2000 Bill Nottingham <notting@redhat.com>
- add patch from Asit Mallick to fix ia64 VHPT disabling

* Wed Nov  8 2000 Bill Nottingham <notting@redhat.com>
- add ia64 module patch

* Wed Nov 08 2000 Erik Troan <ewt@redhat.com>
- updated to test10, builds on ix86

* Wed Nov  1 2000 Bill Nottingham <notting@redhat.com>
- build some stuff statically (bleah)

* Tue Oct 31 2000 Bill Nottingham <notting@redhat.com>
- new ia64 diff from David Mosberger

* Thu Oct 26 2000 Bill Nottingham <notting@redhat.com>
- turn off ptc.g, again (oops)

* Wed Oct 25 2000 Bill Nottingham <notting@redhat.com>
- EFI GUID partition support from Matt Domsch (Matt_Domsch@dell.com)

* Tue Oct 24 2000 Bill Nottingham <notting@redhat.com>
- qlogic 1x160 version 3.19beta
- qlogic 2x00 version 4.15beta
- e1000 v2.5.11
- e100 v1.3.14
- make netfilter build on ia64 (cringe)

* Mon Oct 23 2000 Bill Nottingham <notting@redhat.com>
- update to test9 final
- ia64 updates

* Fri Sep 29 2000 Bill Nottingham <notting@redhat.com>
- clean up requirements (kill devfsd, initscripts)

* Fri Sep 29 2000 Michael K. Johnson <johnsonm@redhat.com>
- updated to tux-2.4.0-test9-H8-nodebug

* Thu Sep 28 2000 Michael K. Johnson <johnsonm@redhat.com>
- updated to tux-2.4.0-test9-G9-nodebug

* Tue Sep 26 2000 Michael K. Johnson <johnsonm@redhat.com>
- updated to tux-2.4.0-test9-G4-nodebug and test9-pre7 kernel
- turned off qla2x00 because it does not know about new scsi init arch
- turned off cciss because of parse error

* Thu Sep 21 2000 Bill Nottingham <notting@redhat.com>
- revert the part of the ia64 patch that requires new modutils for now
- turn off e1000 on ix86/alpha configs

* Tue Sep 19 2000 Bill Nottingham <notting@redhat.com>
- merge in stuff from Matt Domsch
- upgrade ia64 patch from David Mosberger

* Tue Sep 19 2000 Matt_Domsch <Matt_Domsch@dell.com>
- kernel 2.4.0-0.28.4
- Upgraded acenic to v0.47

* Thu Sep 14 2000 Matt_Domsch <Matt_Domsch@dell.com>
- kernel 2.4.0-0.28.3
- Removed I2O again
- Added ia64-000913 patch

- kernel-2.4.0-0.28.2
- removed kern0906.patch
- added 2.4.0-test8-000908 IA-64 patch
- added 2.4.0-test8-ia64 irqfix patch (fixes bigsur infinite IRQ0s)
- enable i2o
- added ia64_iobase export to arch/ia64/kernel/ia64_ksyms.c

* Tue Sep 12 2000 Michael K. Johnson <johnsonm@redhat.com>
- qla2x00 driver rev 4.10
- moved some things from modules to static builds
- sym53c8xx 64-bit patch

* Tue Sep 12 2000 Bill Nottingham <notting@redhat.com>
- make iso9660 & eepro100 static for now
- new ia64 patches from David Mosberger

* Fri Sep  8 2000 Bill Nottingham <notting@redhat.com>
- make nfs & lockd static on ia64; bad things happen otherwise
- update to test8 (turn off sisfb, it doesn't build)

* Thu Sep  7 2000 Bill Nottingham <notting@redhat.com>
- big piles of ia64 updates
- add in e1000 driver, fix modular build
- update acenic to 0.46 for the non-tux case
- update megaraid to 1.10c
- update qla1280 to 3.16b
- build against test7-final (not test8-pre1) for now

* Tue Sep  5 2000 Florian La Roche <Florian.LaRoche@redhat.com>
- update to pcmcia-cs 3.1.20
- remove obsolete pcmcia-cs-3.1.3-3com.patch

* Thu Aug 31 2000 Michael K. Johnson <johnsonm@redhat.com>
- More work on TUX: new version, better integration, still incomplete
- updated to 2.4.0-test8-pre1
- temporarily disabled matrox maven driver because of ICE

* Thu Aug 24 2000 Michael K. Johnson <johnsonm@redhat.com>
- Added TUX (but currently commented out because of insufficient generality)
- Config files mention tux so that the SRPM will still build if you add
  the patch.  However, they will not build TUX in without changes.

* Wed Aug 16 2000 Michael K. Johnson <johnsonm@redhat.com>
- dropped pcmcia-cs copy -f fix in from 2.2

* Tue Aug 15 2000 Bill Nottingham <notting@redhat.com>
- update ia64 stuff

* Tue Aug 15 2000 Jakub Jelinek <jakub@redhat.com>
- update to test7-pre4
- fix emu10k1 build on alpha
- .config updates

* Mon Aug 14 2000 Jakub Jelinek <jakub@redhat.com>
- fix linux-merge-config.awk
- remove /usr/include/{linux,asm*} in kernel-headers %pre

* Thu Aug 10 2000 Bill Nottingham <notting@redhat.com>
- update to test6-final (vger patch is merged)

* Wed Aug  9 2000 Jakub Jelinek <jakub@redhat.com>
- update to test6/pre9
- apply vger patches
- make it build on sparc32

* Tue Aug  8 2000 Bill Nottingham <notting@redhat.com>
- make it build on ia64

* Tue Aug  8 2000 Jakub Jelinek <jakub@redhat.com>
- /usr/include/{linux,asm} are directories
- fix header merging
- update to test6/pre8

* Wed Aug  2 2000 Bill Nottingham <notting@redhat.com>
- add ia32 signal patch for ia64

* Tue Aug  1 2000 Bill Nottingham <notting@redhat.com>
- update to pre5/ia64-728 (argh)
- update qla2x00 scsi driver to 4.0 (from Qlogic)

* Wed Jul 26 2000 Bill Nottingham <notting@redhat.com>
- clean up the %posts some

* Wed Jul 26 2000 Jakub Jelinek <jakub@redhat.com>
- Rename kernel24 subpackages back
- parport fix from Tim Waugh
- make it build on Alpha (hopefully)

* Wed Jul 26 2000 Jakub Jelinek <jakub@redhat.com>
- kill some of the ugly hacks, replace them with other ugly
  hacks so that the package can be built as the main distribution
  kernel or an experimental one.
- fix the export memcpy/memset patch
- add enterprise kernel (64GB kernel) on i686

* Tue Jul 25 2000 Bill Nottingham <notting@redhat.com>
- ugly hacks to get just the headers out

* Tue Jul 25 2000 Jakub Jelinek <jakub@redhat.com>
- kill several unresolved symbols from modules

* Fri Jul 21 2000 Bill Nottingham <notting@redhat.com>
- more tweaks

* Thu Jul 20 2000 Jakub Jelinek <jakub@redhat.com>
- some more tweaks

* Tue Jul 18 2000 Jakub Jelinek <jakub@redhat.com>
- CIPE
- a couple of patchlets
- FHS tweaks

* Wed Jun 21 2000 Bill Nottingham <notting@redhat.com>
- update acenic, megaraid, qla1280 drivers
- minor kernel header tweak for userland

* Sat Jun 17 2000 Bill Nottingham <notting@redhat.com>
- bump up ramdisk size on ia64 & alpha
- compile more stuff into the kernel until modules work better

* Fri Jun 16 2000 Bill Nottingham <notting@redhat.com>
- add ia32 signal handling patch for ia64

* Thu Jun 15 2000 Jakub Jelinek <jakub@redhat.com>
- reenable changeloop patch

* Wed Jun 14 2000 Bill Nottingham <notting@redhat.com>
- merge in loopback fixes from -ac series

* Tue Jun 13 2000 Bill Nottingham <notting@redhat.com>
- ia64 updates (0609 patch)
- module config/versioning updates

* Mon Jun  5 2000 Bill Nottingham <notting@redhat.com>
- merge in the ia64 stuff
- move to /dev/shm

* Sat Jun  3 2000 Jakub Jelinek <jakub@redhat.com>
- fix rhconfig.h (from Bero)

* Mon May 29 2000 Jakub Jelinek <jakub@redhat.com>
- 2.4.0-test1
- changeloop patch
- fix BuildASM
- fix compilation with gcc 2.96
- fix devfsd compilation

* Sat May  6 2000 Bernhard Rosenkraenzer <bero@redhat.com>
- pre7-6
- devfsd 1.3.8
- add even more confusion to the versioning hell ;)
  (so we can deal with pre-pre versions)

* Fri Apr 28 2000 Bill Nottingham <notting@redhat.com>
- update for ia64
- pre6-final
- don't apply abi patch until it stops imploding on boot

* Mon Apr 17 2000 Bernhard Rosenkraenzer <bero@redhat.com>
- 2.3.99pre6-pre3
- update ksymoops to 2.3.4
- update pcmcia to 3.1.14
- devfsd 1.3.4, devfs 162
- link ksymoops statically to get rid of the dependency on a particular
  version of binutils
- adapt abi patch to new kernel interfaces
- minor fixes to spec file

* Wed Mar 22 2000 Bernhard Rosenkraenzer <bero@redhat.com>
- 2.3.99pre3-7
- remove some fixes (they're now in the base version)

* Tue Mar 21 2000 Bernhard Rosenkraenzer <bero@redhat.com>
- Add /var/shm dir
- require initscripts >= 5.03 so we mount /var/shm
- 2.3.99pre3-3
- fix compilation of some buggy drivers
- fix build on sparc64

* Thu Mar 16 2000 Bernhard Rosenkraenzer <bero@redhat.com>
- 2.3.99pre2-3
- replace iBCS with abi, remove patches
- port abi to 2.3.99pre2-3
- fix packaging bug (ksymoops.8* was included in kernel-utils AND
  kernel-pcmcia-cs)
- add devfsd
- fix compilation on alpha (fix various kernel bugs and work
  around a compiler bug)
